/** 
 * 插件模块定义
 */
;APPBASE.define('widgets',function(require, exports, module){
	//js接口规范定义
	var Interface = function(name, methods){
	    var argLen = arguments.length;
	    if(argLen != 2){
	        throw new Error("Interface类的构造函数需要至少两个参数！");            
	    }
	    this.name = name;      //     用来保存接口名称
	    this.methods = [];     //     用来保存要实现的方法名称
	    
	    var i = 0,
	        methodLen = methods.length;
	    for(; i<methodLen; i++){
	        var method = methods[i];
	        if(typeof method != 'string'){
	            throw new Error("Interface类构造函数中的methods参数应该是string[]类型");
	        }
	        methods.push(method);
	    }
	}
	Interface.ensureImpelements = function(object){
		var len = arguments.length;
		if(len < 2){
		   throw new Error("方法Interface.ensureImplements需要至少两个参数!");		
		}
		var i = 1;
		for(; i<len; i++){
			var interface = arguments[i];
			if(interface.constructor  != Interface){
			   throw new Error("方法Interface.ensureImplements参数需要Interface的实例对象!");		}
			var	j = 0,	
				methodsLen = interface.methods.length;
			for(; j<methodsLen; j++){
				var method = interface.methods[j];
				//    这里因为传入的object为类的定义，因此要判断其原型中的方法
				if(!object.prototype[method] || typeof object.prototype[method] != "function"){
					// console.log("方法Interface.ensureImplements : object 没有实现" + interface.name + " 接口. 方法" + method + " 没有被找到!");
					return false;
				}
			}
		}
		return true;
	}
	//插件类对象
	var Widget = new Interface('Widget', ['init','callback','data']);//定义插件有哪些方法
	
	/**插件管理对象**/
	var Widgets = function(){
		this.widgetMap = {};//插件对象维护
		this.noRefresh = false; //是否不刷新
	}
	
	/**
	 * 插件管理对象方法定义
	 */
	Widgets.prototype = {
		add:function(id,widget){//新增插件
			if(Interface.ensureImpelements(widget, Widget)){
				this.widgetMap[id] = widget;
			}
		},
		remove:function(id){//删除插件
			this.widgetMap[id] = null;
		},
		replace:function(id,widget,func){//替换插件
			if(func != null){
				var wg = this.widgetMap[id];
				if(wg != null){
					wg.prototype[widget] = func;
				}
				return;
			}
			if(Interface.ensureImpelements(widget, Widget)){
				this.add(id,widget);
			}
		},
		get:function(id){//获取一个控件实例
			if(this.widgetMap[id]){
				return new this.widgetMap[id]();
			}
			return null;
		},
		setNoRefresh:function(noRefresh){//设置是否刷新
			this.noRefresh = noRefresh;
		}
	};
	
	module.exports = new Widgets();
});