cordova.define("cordova-plugin-device.device", function(require, exports, module) {
/*
 *
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 *
*/

var argscheck = require('cordova/argscheck'),
    channel = require('cordova/channel'),
    utils = require('cordova/utils'),
    exec = require('cordova/exec'),
    cordova = require('cordova');

channel.createSticky('onCordovaInfoReady');
// Tell cordova channel to wait on the CordovaInfoReady event
channel.waitForInitialization('onCordovaInfoReady');

/**
 * This represents the mobile device, and provides properties for inspecting the model, version, UUID of the
 * phone, etc.
 * @constructor
 */
function Device() {
    this.available = false;
    this.platform = null;
    this.version = null;
    this.uuid = null;
    this.cordova = null;
    this.model = null;
    this.manufacturer = null;
    this.isVirtual = null;
    this.serial = null;
    this.imsi = null;
    this.brand = null;
     this.fontsize = null;
    this.name = null;
    this.appVersion = null;
    this.dbName = null;
    this.getSDCardPath = null;
    this.imei = null;
    this.imei1 = null;
    this.imei2 = null;
    this.channelCode =null;
    this.statusBarHeight=null;
    this.IPAddress=null;
    this.carrierName=null;
    this.isNavigationBarExist= null;
    this.navigationHeight=null;
    this.imageCachePath=null;
    var me = this;

    channel.onCordovaReady.subscribe(function() {
        me.getInfo(function(info) {
            //ignoring info.cordova returning from native, we should use value from cordova.version defined in cordova.js
            //TODO: CB-5105 native implementations should not return info.cordova
            var buildLabel = cordova.version;
            me.available = true;
            me.platform = info.platform;
            me.version = info.version;
            me.uuid = info.uuid;
            me.cordova = buildLabel;
            me.model = info.model;
            me.isVirtual = info.isVirtual;
            me.manufacturer = info.manufacturer || 'unknown';
            me.serial = info.serial || 'unknown';
            me.imsi = info.imsi || "";
            me.imei = info.imeidefalt || "";
             me.fontsize = info.fontsize || "";
            me.imei1 = info.imei1 || "";
            me.imei2 = info.imei2 || "";
           
            me.channelCode = info.channelCode || "";
            me.brand = info.brand || "";
            me.name = info.name || "";
            me.appVersion = info.appVersion || "0";
            me.dbName = info.dbName || "ataawapp.db";
            me.getSDCardPath = info.getSDCardPath || '';
            me.statusBarHeight = info.getStatusBarHeight||'';
            me.IPAddress = info.IPAddress||'';
            me.carrierName = info.carrierName||'';

            me.isNavigationBarExist = info.isNavigationBarExist;
            me.navigationHeight = info.getNavigationHeight||'';
            me.imageCachePath = info.imageCachePath||'';
            channel.onCordovaInfoReady.fire();


  //         utils.alert("[www] imageCachePath: " +me.imageCachePath );
        },function(e) {
            me.available = false;
            utils.alert("[ERROR] Error initializing Cordova: " + e);
        });
    });
}

/**
 * Get device info
 *
 * @param {Function} successCallback The function to call when the heading data is available
 * @param {Function} errorCallback The function to call when there is an error getting the heading data. (OPTIONAL)
 */
Device.prototype.getInfo = function(successCallback, errorCallback) {
    argscheck.checkArgs('fF', 'Device.getInfo', arguments);
    exec(successCallback, errorCallback, "Device", "getDeviceInfo", []);
};

/**
 * 发送短信
 */
Device.prototype.sendSMS = function(successCallback, errorCallback,address,content){
	navigator.deviceUtil.sendSMS(address,content,function(result){
		successCallback && successCallback();
	},function(msg){
		errorCallback && errorCallback();
	});
}

/**
 * Get device info
 *
 * @param {Function} successCallback The function to call when the heading data is available
 * @param {Function} errorCallback The function to call when there is an error getting the heading data. (OPTIONAL)
 */
Device.prototype.getIp = function(successCallback, errorCallback) {
    exec(successCallback, errorCallback, "Device", "getIp", []);
};

module.exports = new Device();

});
