cordova.define("http.Http", function(require, exports, module) {
	var exec = require('cordova/exec');
	
	/**
	 * Http请求对象
	 */
	var Http = function(){
		/**
		 * 回调方法map
		 */
		this.callbackMap = {};
	}
	
	/**
	 * Http请求
	 */
	Http.prototype = {
			/**
			 * 执行回调方法
			 */
			excuteCallback:function(callbackId,callbackName,data){
				if(this.callbackMap[callbackId] && this.callbackMap[callbackId][callbackName]){
					this.callbackMap[callbackId][callbackName](data);
					this.callbackMap[callbackId][callbackName] = null;
				}
			},
			/**
			 * 根据请求url生成唯一的callbackId
			 */
			generateCallbackId:function(url){
				var str = url.replace(/[:|/|.]/g,'');
				if(str.length > 10){
					return str.substring(str.length - 10) + parseInt(Math.random() * 1000000);
				}
				return str + parseInt(Math.random() * 1000000);
			},
			/**
			 * 必填参数校验
			 */
			validate:function(option){
				//判断入场是否为空，或者url是否为空
				if(!option || option.url == null || "" == option.url){
					return false;
				}
				option.beforeSend && option.beforeSend();
				/**
				 * 插件调用时的相关回调方法定义
				 */
				var callback = {
					complete:option.complete,
					uploading:option.uploading,
					downloading:option.downloading
				};
				var callbackId = this.generateCallbackId(option.url);
				this.callbackMap[callbackId] = callback;
				option.callbackId = callbackId;
				return true;
			},
			/**
			 * 将json参数转化成数组形式
			 */
			toArgs:function(option){
				//头信息如果没有设置，则进行默认设置{}
				var headers = option.header;
				if(!headers){
					headers = {};
				}
				//参数如何没有设置，则进行默认设置{}
				var data = option.data;
				if(!data){
					data = {};
				}
				window.FIX_SIX_OPT.fixUrl(option);
				var args = [
					option.url,
					data,
					headers,
					{
						"ssl":option.ssl,
						"des":option.des,
						"newDes":option.newDes,
						"timeout":option.timeout,
						"charset":option.charset
					},
					option.callbackId
				];
				return args;
			},
			/**
			 * 将json参数转化成数组形式
			 */
			toArgsForDownload:function(option){
				//头信息如果没有设置，则进行默认设置{}
				var headers = option.header;
				if(!headers){
					headers = {};
				}
				//参数如何没有设置，则进行默认设置{}
				var data = option.data;
				if(!data){
					data = {};
				}
				var args = [
					option.url,
					data,
					headers,
					option.filePath,
					option.callbackId
				];
				return args;
			},
			/**
			 * get请求
			 * @param {Object} option
			 * @param {String} option.url 请求的地址 
			 * @param {Object} option.data 请求的数据
			 * @param {Object} option.header 请求开头包含的信息
			 * @param {Function} option.beforeSend 发送前执行的方法
			 * @param {Function} option.complete 发送完成后执行的方法
			 * @param {Function} option.success 请求成功执行的方法
			 * @param {Function} option.error 请求失败执行的方法
			 * @param {Integer} option.ssl 请求协议 (1:true, 0:false)
			 * @param {Integer} option.timeout 请求超时时间设置毫秒数(如 60000毫秒数)
			 * @param {Integer} option.des 是否需要进行参数加密 (1:true, 0:false)
			 * @param {Integer} option.charset 加密的编码 (0:utf-8, 1:GBK)
			 */
			get:function(option){
				if(!this.validate(option)){
					return;
				}
				exec(option.success,option.error,"Http","get",this.toArgs(option));
			},
			
			/**
			 * post请求
			 * @param {Object} option
			 * @param {String} option.url 请求的地址 
			 * @param {Object} option.data 请求的数据
			 * @param {Object} option.header 请求开头包含的信息
			 * @param {Function} option.beforeSend 发送前执行的方法
			 * @param {Function} option.complete 发送完成后执行的方法
			 * @param {Function} option.success 请求成功执行的方法
			 * @param {Function} option.error 请求失败执行的方法
			 * @param {Integer} option.ssl 请求协议 (1:true, 0:false)
			 * @param {Integer} option.timeout 请求超时时间设置毫秒数(如 60000毫秒数)
			 * @param {Integer} option.des 是否需要进行参数加密 (1:true, 0:false)
			 * @param {Integer} option.charset 加密的编码 (0:utf-8, 1:GBK)
			 */
			post:function(option){
				if(!this.validate(option)){
					return;
				}
				exec(option.success,option.error,"Http","post",this.toArgs(option));
			},
			
			/**
			 * 请求下载
			 * @param {Object} option
			 * @param {String} option.url 请求的地址 
			 * @param {Object} option.data 请求的数据
			 * @param {Object} option.header 请求开头包含的信息
			 * @param {Function} option.beforeSend 发送前执行的方法
			 * @param {Function} option.downloading 下载中方法回调
			 * @param {Function} option.complete 发送完成后执行的方法
			 * @param {Function} option.success 请求成功执行的方法
			 * @param {Function} option.error 请求失败执行的方法
			 * @param {Boolean} option.notifShow 是否通知栏显示
			 */
			download:function(option){
				if(!this.validate(option)){
					return;
				}
				
				var fileTransfer = new FileTransfer();
				var uri = encodeURI(option.url);
				fileTransfer.download(
				    uri,
				    option.filePath,
				    function(entry) {
				    	if(entry && entry.nativeURL && entry.nativeURL.indexOf('file://') >= 0){
				    		entry.absolutedURL = entry.nativeURL.substring(7);
				    	}
				    	option.success && option.success(entry);
				    },
				    function(error) {
				    	option.error && option.error(error);
				    },
				    false,
				    {
				    	notifShow:option.notifShow,
				    	showTicker:option.showTicker,
				    	overwritten: option.overwritten,
				    	continueDoing:option.continueDoing
				    }


				);
				/**
				 * 下载中
				 */
				fileTransfer.onprogress = function(progress){
					option.downloading && option.downloading({downloaded:progress.loaded,total:progress.total});
				};
				return fileTransfer;
				//exec(option.success,option.error,"Http","download",this.toArgsForDownload(option));
			},
			
			/**
			 * 请求上传
			 * @param {Object} option
			 * @param {String} option.url 请求的地址 
			 * @param {Object} option.data 请求的数据
			 * @param {Object} option.header 请求开头包含的信息
			 * @param {Function} option.beforeSend 发送前执行的方法
			 * @param {Function} option.complete 发送完成后执行的方法
			 * @param {Function} option.success 请求成功执行的方法
			 * @param {Function} option.error 请求失败执行的方法
			 * @param {Function} option.ssl 请求协议
			 */
			upload:function(option){
				var args = [
				            option.url,
				            option.data,
				            option.header,
				            option.ssl,
				            ];
				var success = option.success;
				var error = option.error;
				var beforeSend = option.beforeSend;
				var complete = option.complete;
				exec(success,error,"Http","upload",args);
			}
			
	}
	
	module.exports = new Http();
});

/**
 * 六期服务架构升级适配类
 */
window.FIX_SIX_ZT_SERVICE = {
    "keys": {
        "jszt_rest_queryApkVersion": "rest_queryApkVersion",
        "jszt_rest_login2UserInfo": "rest_login2UserInfo",
        "jszt_uniformity_searchZhanDanMonthSix": "uniformity_searchZhanDanMonthSix",
        "jszt_rest_queryIntroducer": "rest_queryIntroducer",
        "jszt_jiFenActon_getSignedDays": "jiFenActon_getSignedDays",
        "jszt_lifehall_checkBlackUser": "lifehall_checkBlackUser",
        // 触点回单接口
        "ZTCHANNEL-MAIN_query_queryReceipt": "query_queryReceipt",
        "jszt_uniformity_searchNameProduct": "product_searchNameProduct",
        "jszt_rest_verifyCode": "rest_verifyCode",
        "jszt_rest_bill": "product_bill",
        // "jszt_uniformity_checkIsShowPackage": "user_checkIsShowPackage",
        "jszt_rest_package": "package_package",
        "jszt_rest_usedtrafcard": "wifi_usedtrafcard",
        "ZTCHANNEL-MAIN_config_offerId": "business_offerId",
        "jszt_rest_broadbandlist": "rest_broadbandlist",
        "jszt_rest_paytrafcard": "wifi_paytrafcard",
        "ZTCHANNEL-MAIN_config_level": "user_level",
        "jszt_uniformity_searchCallCurrMonthBillReqWithCache": "user_searchCallCurrMonthBillReqWithCache",
        "jszt_rest_voiceticket": "rest_voiceticket",
        "jszt_liuliang_getNewFlowSearchSort": "package_getNewFlowSearchSort",
        "jszt_recharge_queryReturnPlan": "recharge_queryReturnPlan",
        "ZTCHANNEL-MAIN_config_getAccountBalance": "user_getAccountBalance",
        "jszt_rest_querywlandetail": "rest_querywlandetail",
        "jszt_ztauth_verifySamePerson": "recharge_verifySamePerson",
        "controlCenter_UpdateUseInfo_cacheAppUser": "user_cacheAppUser",
        "jszt_recharge_queryRechargeRecord": "recharge_queryRechargeRecord",
        "jszt_rest_cnet": "rest_cnet",
        "jszt_rest_queryProductUnsubscribeList": "rest_queryProductUnsubscribeList",
        "jszt_rest_queryPUK": "rest_queryPUK",
        "jszt_rest_userinfo": "rest_userinfo",
        "jszt_ipauth_ipcumulation": "ipauth_ipcumulation",
        "jszt_rest_accnbrusedbill": "rest_accnbrusedbill",
        "jszt_rest_updateuserinfo": "rest_updateuserinfo",
        "jszt_liuliang_getNewFlowSearchSortRecord": "package_getNewFlowSearchSortRecord",
        "jszt_rest_queryCardFee": "wifi_queryCardFee",
        "jszt_rest_longcall": "rest_longcall",
        "jszt_uniformity_searchCallBalanceReqWithCache": "user_searchCallBalanceReqWithCache",
        "jszt_uniformity_searchZhangDan": "product_searchZhangDan",
        "wifimw_indexCtrl_getByTelephone": "user_getByTelephone",
        "jszt_rest_querynewwlandetail": "rest_querynewwlandetail",
        "jszt_rest_wifilist": "wifi_wifilist",
        "jszt_rest_shortmsg": "rest_shortmsg",
        "jszt_rest_mmse": "rest_mmse",
        "jszt_rest_verifyuserinfo": "rest_verifyuserinfo",
        "jszt_rest_ticket": "rest_ticket",
        "jszt_rest_internationalRoaming": "rest_internationalRoaming",
        "jszt_rest_resetpwdnew": "rest_resetpwdnew",
        // "jszt_promotiontoken_isOldUser": "user_isOldUser",
        "jszt_rest_wlanoncekey": "rest_wlanoncekey",
        "jszt_rest_recomendModules": "rest_recomendModules",
        "jszt_rest_vsopDetail": "rest_vsopDetail",
        "ZTCHANNEL-MAIN_config_checkAdministrator": "user_checkAdministrator",
        "jszt_rest_mobilenet": "rest_mobilenet",
        "ZTCHANNEL-MAIN_config_getProdList": "user_getProdList",
        "jszt_rest_wifiblance": "rest_wifiblance",
        "jszt_rest_updatepwd": "rest_updatepwd"
    },
    "vals": {
        "rest_queryApkVersion": {
            "code": "base-00003",
            "url": "http://zt-app.go189.cn/zt-app/rest/queryApkVersion"
        },
        "rest_login2UserInfo": {
            "code": "rest-00026",
            "url": "http://zt-service.go189.cn/zt-service/rest/login2UserInfo"
        },
        "uniformity_searchZhanDanMonthSix": {
            "code": "product-00004",
            "url": "http://zt-service.go189.cn/zt-service/uniformity/searchZhanDanMonthSix"
        },
        "rest_queryIntroducer": {
            "code": "rest-00028",
            "url": "http://zt-service.go189.cn/zt-service/rest/queryIntroducer"
        },
        "jiFenActon_getSignedDays": {
            "code": "jiFenActon-00002",
            "url": "http://zt-score.go189.cn/zt-score/jiFenActon/getSignedDays"
        },
        "lifehall_checkBlackUser": {
            "code": "user-00013",
            "url": "http://zt-service.go189.cn/zt-service/lifehall/checkBlackUser"
        },
        "query_queryReceipt": {
            "code": "query-00002",
            "url": "http://zt-service.go189.cn/zt-service/query/queryReceipt"
        },
        "user_searchCallCurrMonthBillReqWithCache": {
            "code": "user-00002",
            "url": "http://zt-service.go189.cn/zt-service/user/searchCallCurrMonthBillReqWithCache"
        },
        "user_getByTelephone": {
            "code": "user-00007",
            "url": "http://zt-service.go189.cn/zt-service/user/getByTelephone"
        },
        "recharge_queryRechargeRecord": {
            "code": "recharge-00001",
            "url": "http://zt-service.go189.cn/zt-service/recharge/queryRechargeRecord"
        },
        "rest_longcall": {
            "code": "rest-00024",
            "url": "http://zt-service.go189.cn/zt-service/rest/longcall"
        },
        "rest_querywlandetail": {
            "code": "rest-00021",
            "url": "http://zt-service.go189.cn/zt-service/rest/querywlandetail"
        },
        "rest_mobilenet": {
            "code": "rest-00018",
            "url": "http://zt-service.go189.cn/zt-service/rest/mobilenet"
        },
        "rest_querynewwlandetail": {
            "code": "rest-00017",
            "url": "http://zt-service.go189.cn/zt-service/rest/querynewwlandetail"
        },
        "user_checkIsShowPackage": {
            "code": "user-00004",
            "url": "http://zt-service.go189.cn/zt-service/user/checkIsShowPackage"
        },
        "rest_queryProductUnsubscribeList": {
            "code": "rest-00003",
            "url": "http://zt-service.go189.cn/zt-service/rest/queryProductUnsubscribeList"
        },
        "rest_userinfo": {
            "code": "rest-00004",
            "url": "http://zt-service.go189.cn/zt-service/rest/userinfo"
        },
        "rest_updatepwd": {
            "code": "rest-00006",
            "url": "http://zt-service.go189.cn/zt-service/rest/updatepwd"
        },
        "wifi_queryCardFee": {
            "code": "wifi-00002",
            "url": "http://zt-service.go189.cn/zt-service/wifi/queryCardFee"
        },
        "product_bill": {
            "code": "product-00003",
            "url": "http://zt-service.go189.cn/zt-service/product/bill"
        },
        "user_getAccountBalance": {
            "code": "user-00010",
            "url": "http://zt-service.go189.cn/zt-service/user/getAccountBalance"
        },
        "wifi_usedtrafcard": {
            "code": "wifi-00004",
            "url": "http://zt-service.go189.cn/zt-service/wifi/usedtrafcard"
        },
        "rest_recomendModules": {
            "code": "rest-00014",
            "url": "http://zt-service.go189.cn/zt-service/rest/recomendModules"
        },
        "rest_shortmsg": {
            "code": "rest-00016",
            "url": "http://zt-service.go189.cn/zt-service/rest/shortmsg"
        },
        "rest_verifyuserinfo": {
            "code": "rest-00007",
            "url": "http://zt-service.go189.cn/zt-service/rest/verifyuserinfo"
        },
        "rest_accnbrusedbill": {
            "code": "rest-00012",
            "url": "http://zt-service.go189.cn/zt-service/rest/accnbrusedbill"
        },
        "rest_updateuserinfo": {
            "code": "rest-00005",
            "url": "http://zt-service.go189.cn/zt-service/rest/updateuserinfo"
        },
        "rest_broadbandlist": {
            "code": "rest-00009",
            "url": "http://zt-service.go189.cn/zt-service/rest/broadbandlist"
        },
        "ipauth_ipcumulation": {
            "code": "ipauth-00001",
            "url": "http://zt-service.go189.cn/zt-service/ipauth/ipcumulation"
        },
        "business_offerId": {
            "code": "business-00001",
            "url": "http://zt-service.go189.cn/zt-service/business/offerId"
        },
        "user_isOldUser": {
            "code": "user-00001",
            "url": "http://zt-service.go189.cn/zt-service/user/isOldUser"
        },
        "wifi_paytrafcard": {
            "code": "wifi-00003",
            "url": "http://zt-service.go189.cn/zt-service/wifi/paytrafcard"
        },
        "user_checkAdministrator": {
            "code": "user-00005",
            "url": "http://zt-service.go189.cn/zt-service/user/checkAdministrator"
        },
        "package_getNewFlowSearchSortRecord": {
            "code": "package-00002",
            "url": "http://zt-service.go189.cn/zt-service/package/getNewFlowSearchSortRecord"
        },
        "rest_internationalRoaming": {
            "code": "rest-00013",
            "url": "http://zt-service.go189.cn/zt-service/rest/internationalRoaming"
        },
        "user_searchCallBalanceReqWithCache": {
            "code": "user-00003",
            "url": "http://zt-service.go189.cn/zt-service/user/searchCallBalanceReqWithCache"
        },
        "package_package": {
            "code": "package-00003",
            "url": "http://zt-service.go189.cn/zt-service/package/package"
        },
        "user_level": {
            "code": "user-00006",
            "url": "http://zt-service.go189.cn/zt-service/user/level"
        },
        "product_searchZhangDan": {
            "code": "product-00002",
            "url": "http://zt-service.go189.cn/zt-service/product/searchZhangDan"
        },
        "rest_wifiblance": {
            "code": "rest-00010",
            "url": "http://zt-service.go189.cn/zt-service/rest/wifiblance"
        },
        "rest_resetpwdnew": {
            "code": "rest-00001",
            "url": "http://zt-service.go189.cn/zt-service/rest/resetpwdnew"
        },
        "package_getNewFlowSearchSort": {
            "code": "package-00001",
            "url": "http://zt-service.go189.cn/zt-service/package/getNewFlowSearchSort"
        },
        "product_searchNameProduct": {
            "code": "product-00001",
            "url": "http://zt-service.go189.cn/zt-service/product/searchNameProduct"
        },
        "recharge_verifySamePerson": {
            "code": "recharge-00003",
            "url": "http://zt-service.go189.cn/zt-service/recharge/verifySamePerson"
        },
        "rest_verifyCode": {
            "code": "rest-00008",
            "url": "http://zt-service.go189.cn/zt-service/rest/verifyCode"
        },
        "rest_vsopDetail": {
            "code": "rest-00020",
            "url": "http://zt-service.go189.cn/zt-service/rest/vsopDetail"
        },
        "user_cacheAppUser": {
            "code": "user-00008",
            "url": "http://zt-service.go189.cn/zt-service/user/cacheAppUser"
        },
        "wifi_wifilist": {
            "code": "wifi-00001",
            "url": "http://zt-service.go189.cn/zt-service/wifi/wifilist"
        },
        "rest_mmse": {
            "code": "rest-00019",
            "url": "http://zt-service.go189.cn/zt-service/rest/mmse"
        },
        "rest_cnet": {
            "code": "rest-00023",
            "url": "http://zt-service.go189.cn/zt-service/rest/cnet"
        },
        "rest_voiceticket": {
            "code": "rest-00015",
            "url": "http://zt-service.go189.cn/zt-service/rest/voiceticket"
        },
        "recharge_queryReturnPlan": {
            "code": "recharge-00002",
            "url": "http://zt-service.go189.cn/zt-service/recharge/queryReturnPlan"
        },
        "rest_queryPUK": {
            "code": "rest-00011",
            "url": "http://zt-service.go189.cn/zt-service/rest/queryPUK"
        },
        "rest_ticket": {
            "code": "rest-00002",
            "url": "http://zt-service.go189.cn/zt-service/rest/ticket"
        },
        "rest_wlanoncekey": {
            "code": "rest-00022",
            "url": "http://zt-service.go189.cn/zt-service/rest/wlanoncekey"
        },
        "user_getProdList": {
            "code": "user-00009",
            "url": "http://zt-service.go189.cn/zt-service/user/getProdList"
        }
    }
};
window.FIX_SIX_ZT_SCORE = {
    "keys": {
        "jszt_point_getsignpointinitdata": "point_getsignpointinitdata",
        //"jszt_point_getsignpointinitdata": "point_getsignpointinitdata",
        //"jszt_point_displayMission": "point_displayMission",
        //"jszt_point_getwxpointinitdata": "point_getwxpointinitdata",
        //"jszt_point_teQuanJifenQuery": "point_teQuanJifenQuery",
        "jszt_replenishPoint_giveTaskPoint": "replenishPoint_giveTaskPoint",
        //"jszt_point_getsignpointhistory2": "point_getsignpointhistory2",
        "jszt_replenishPoint_isShowReplenishSign": "replenishPoint_isShowReplenishSign",
        //"jszt_point_teQuanJifenHistory": "point_teQuanJifenHistory",
        //"jszt_point_sendpointshare": "point_sendpointshare",
        "jszt_replenishPoint_insertUserTask": "replenishPoint_insertUserTask",
        //"jszt_point_teQuanJifenSign": "point_teQuanJifenSign",
        "jszt_replenishPoint_ztluckyGetPoint": "replenishPoint_ztluckyGetPoint",
        //"jszt_point_getsignpointhistory": "point_getsignpointhistory",
        //"jszt_point_signsendpoint": "point_signsendpoint"
    },
    "vals": {
        "point_getsignpointinitdata": {
            "code": "point-00003",
            "url": "http://zt-score.go189.cn/zt-score/point/getsignpointinitdata"
        },
        "point_teQuanJifenSign": {
            "code": "point-00009",
            "url": "http://zt-score.go189.cn/zt-score/point/teQuanJifenSign"
        },
        "point_getwxpointinitdata": {
            "code": "point-00004",
            "url": "http://zt-score.go189.cn/zt-score/point/getwxpointinitdata"
        },
        "point_sendpointshare": {
            "code": "point-00002",
            "url": "http://zt-score.go189.cn/zt-score/point/sendpointshare"
        },
        "replenishPoint_isShowReplenishSign": {
            "code": "replenishPoint-00001",
            "url": "http://zt-score.go189.cn/zt-score/replenishPoint/isShowReplenishSign"
        },
//        "point_getsignpointhistory2": {
//            "code": "point-00007",
//            "url": "http://zt-score.go189.cn/zt-score/point/getsignpointhistory2"
//        },
//        "point_getsignpointinitdata": {
//            "code": "point-00003",
//            "url": "http://zt-score.go189.cn/zt-score/point/getsignpointinitdata"
//        },
        "replenishPoint_giveTaskPoint": {
            "code": "replenishPoint-00003",
            "url": "http://zt-score.go189.cn/zt-score/replenishPoint/giveTaskPoint"
        },
        "point_displayMission": {
            "code": "point-00001",
            "url": "http://zt-score.go189.cn/zt-score/point/displayMission"
        },
        "point_teQuanJifenQuery": {
            "code": "point-00010",
            "url": "http://zt-score.go189.cn/zt-score/point/teQuanJifenQuery"
        },
        "point_getsignpointhistory": {
            "code": "point-00006",
            "url": "http://zt-score.go189.cn/zt-score/point/getsignpointhistory"
        },
//        "point_signsendpoint": {
//            "code": "point-00005",
//            "url": "http://zt-score.go189.cn/zt-score/point/signsendpoint"
//        },
        "point_teQuanJifenHistory": {
            "code": "point-00008",
            "url": "http://zt-score.go189.cn/zt-score/point/teQuanJifenHistory"
        },
        "replenishPoint_ztluckyGetPoint": {
            "code": "replenishPoint-00004",
            "url": "http://zt-score.go189.cn/zt-score/replenishPoint/ztluckyGetPoint"
        },
        "replenishPoint_insertUserTask": {
            "code": "replenishPoint-00002",
            "url": "http://zt-score.go189.cn/zt-score/replenishPoint/insertUserTask"
        }
    }
};
window.FIX_SIX_ZT_PAY = {
    "keys": {
        "ZT-PAY_recharge_wapRecharge": "recharge_wapRecharge",
        "ZT-PAY_pay_queryPayInfo": "pay_queryPayInfo",
        "ZT-PAY_pay_wxPay": "pay_wxPay",
        "ZT-PAY_recharge_rechargeCallback": "recharge_rechargeCallback",
        "ZT-PAY_pay_wap": "pay_wap",
        "ZT-PAY_flowPay_wxPay": "flowPay_wxPay",
        "ZT-PAY_flowPay_wap": "flowPay_wap",
        "ZT-PAY_recharge_wxRecharge": "recharge_wxRecharge"
    },
    "vals": {
        "recharge_rechargeCallback": {
            "code": "pay-00006",
            "url": "http://zt-pay.go189.cn/zt-pay/recharge/rechargeCallback"
        },
        "pay_wap": {
            "code": "pay-00001",
            "url": "http://zt-pay.go189.cn/zt-pay/pay/wap"
        },
        "flowPay_wxPay": {
            "code": "pay-00008",
            "url": "http://zt-pay.go189.cn/zt-pay/flowPay/wxPay"
        },
        "recharge_wxRecharge": {
            "code": "pay-00005",
            "url": "http://zt-pay.go189.cn/zt-pay/recharge/wxRecharge"
        },
        "pay_wxPay": {
            "code": "pay-00002",
            "url": "http://zt-pay.go189.cn/zt-pay/pay/wxPay"
        },
        "flowPay_wap": {
            "code": "pay-00007",
            "url": "http://zt-pay.go189.cn/zt-pay/flowPay/wap"
        },
        "pay_queryPayInfo": {
            "code": "pay-00003",
            "url": "http://zt-pay.go189.cn/zt-pay/pay/queryPayInfo"
        },
        "recharge_wapRecharge": {
            "code": "pay-00004",
            "url": "http://zt-pay.go189.cn/zt-pay/recharge/wapRecharge"
        }
    }
};
window.FIX_SIX_ZT_MALL = {
    "keys": {
        "market_sales_queryNumberListNotFour": "sales_queryNumberListNotFour",
        "market_order_newMobileSaveOrder": "order_newMobileSaveOrder",
        "market_oldUserBuyPhone_saveNetWorkInfo": "oldUserBuyPhone_saveNetWorkInfo",
        "market_sales_validateStockCanSell": "sales_validateStockCanSell",
        "market_order_getServerRealTime": "order_getServerRealTime",
        "market_sales_queryNumberListTag": "sales_queryNumberListTag",
        "market_currency_queryDetailInfo": "discount_queryDetailInfo",
        "market_currency_queryOldGoods": "oldUser_queryOldGoods",
        "market_orderRelate_orderAfterSales": "order_orderAfterSales",
        "market_currency_countFee": "order_countFee",
        "market_currency_queryInfo": "oldUser_queryInfo",
        "market_familyNum_queryFamilyNumList": "number_queryFamilyNumList",
        "market_order_queryOrderCashier": "order_queryOrderCashier",
        "market_ItvOnlineStatus_getNearly50Numbers": "user_getNearly50Numbers",
        "market_order_salesList": "goods_salesList",
        "market_pcorder_saveNetWorkInfo": "pcorder_saveNetWorkInfo",
        "market_suTongKa_queryOrderList": "goods_queryOrderList",
        "market_newfamilyhi_queryuserdetail": "user_queryuserdetail",
        "market_orderRelate_orderEvaluation": "order_orderEvaluation",
        "market_currency_queryOldUser": "oldUser_queryOldUser",
        "market_ItvOnlineStatus_getAmountOfAccess": "user_getAmountOfAccess",
        "market_pcorder_recordRecommInfo": "pcorder_recordRecommInfo",
        "market_currency_queryGoodsAgreement": "goods_queryGoodsAgreement",
        "market_order_cancelOrder": "order_cancelOrder",
        "market_currency_checkVoucherInfo": "discount_checkVoucherInfo",
        "market_currency_queryVoucherList": "discount_queryVoucherList",
        "market_order_saveZWOrder": "order_saveZWOrder",
        "market_order_saveOrder": "order_saveOrder",
        "market_orderRelate_orderLogisticsTrack": "order_orderLogisticsTrack",
        "market_order_saveFuNum": "number_saveFuNum",
        "market_sales_queryNumberList": "number_queryNumberList",
        "market_order_saveITVOrder": "order_saveITVOrder",
        "market_pcorder_queryOrderDetail": "pcorder_queryOrderDetail",
        "market_familyNum_getFamilyNumList": "number_getFamilyNumList",
        "market_suTongKa_queryGoodsList": "goods_queryGoodsList",
        "market_order_saveNetWorkInfo": "number_saveNetWorkInfo",
        "market_fuKaRelated_fuKaSubmit": "order_fuKaSubmit",
        "market_currency_queryRedEnvelope": "discount_queryRedEnvelope",
        "market_currency_queryEffectiveInfo": "discount_queryEffectiveInfo",
        "market_currency_queryConditionList": "goods_queryConditionList",
        "market_seckill_checkSeckillInfo": "order_queryLoveNumberList",
        "market_currency_receiveVoucher": "discount_receiveVoucher",
        "market_order_queryOrderDetail": "order_queryOrderDetail",
        "market_order_queryNetWorkInfo": "number_queryNetWorkInfo",
        "market_sales_getMoney": "order_getMoney",
        "market_pcorder_saveOrder": "pcorder_saveOrder",
        "market_suTongKa_checkWhiteList": "goods_checkWhiteList",
        "market_currency_queryLoginName": "user_queryLoginName",
        "market_currency_queryNumberByIdentity": "user_queryNumberByIdentity",
        "market_sales_queryGoodsDetail": "goods_queryGoodsDetail",
        "market_sales_queryLoveNumberList": "number_queryLoveNumberList",
        "market_order_queryOrderList": "order_queryOrderList",
        "market_order_saveXuYueOrder": "order_saveXuYueOrder"
    },
    "vals": {
        "sales_queryNumberListNotFour": {
            "code":"number-00010",
            "url":"http://zt-mall.go189.cn/zt-mall/sales/queryNumberListNotFour"
        },
        "order_newMobileSaveOrder": {
            "code":"order-00024",
            "url":"http://zt-mall.go189.cn/zt-mall/order/newMobileSaveOrder"
        },
        "oldUserBuyPhone_saveNetWorkInfo": {
            "code":"number-00008",
            "url":"http://zt-mall.go189.cn/zt-mall/number/saveNetWorkInfoForBuyPhone"
        },
        "sales_validateStockCanSell": {
            "code":"goods-00008",
            "url":"http://zt-mall.go189.cn/zt-mall/goods/validateStockCanSell"
        },
        "order_getServerRealTime": {
            "code":"order-00020",
            "url":"http://zt-mall.go189.cn/zt-mall/order/getServerRealTime"
        },
        "sales_queryNumberListTag": {
            "code":"homePage-00001",
            "url":"http://zt-mall.go189.cn/zt-mall/sales/queryNumberListTag"
        },
        "discount_checkVoucherInfo": {
            "code": "discount-00003",
            "url": "http://zt-mall.go189.cn/zt-mall/discount/checkVoucherInfo"
        },
        "oldUser_queryInfo": {
            "code": "oldUser-00001",
            "url": "http://zt-mall.go189.cn/zt-mall/oldUser/queryInfo"
        },
        "discount_queryVoucherList": {
            "code": "discount-00004",
            "url": "http://zt-mall.go189.cn/zt-mall/discount/queryVoucherList"
        },
        "discount_receiveVoucher": {
            "code": "discount-00005",
            "url": "http://zt-mall.go189.cn/zt-mall/discount/receiveVoucher"
        },
        "number_saveFuNum": {
            "code": "number-00003",
            "url": "http://zt-mall.go189.cn/zt-mall/number/saveFuNum"
        },
        "discount_queryDetailInfo": {
            "code": "discount-00001",
            "url": "http://zt-mall.go189.cn/zt-mall/discount/queryDetailInfo"
        },
        "order_queryOrderCashier": {
            "code": "order-00008",
            "url": "http://zt-mall.go189.cn/zt-mall/order/queryOrderCashier"
        },
        "number_queryNumberList": {
            "code": "number-00004",
            "url": "http://zt-mall.go189.cn/zt-mall/number/queryNumberList"
        },
        "order_saveITVOrder": {
            "code": "order-00004",
            "url": "http://zt-mall.go189.cn/zt-mall/order/saveITVOrder"
        },
        "pcorder_saveNetWorkInfo": {
            "code": "pcorder-0003",
            "url": "http://zt-mall.go189.cn/zt-mall/pcorder/saveNetWorkInfo"
        },
        "number_queryLoveNumberList": {
            "code": "number-00005",
            "url": "http://zt-mall.go189.cn/zt-mall/number/queryLoveNumberList"
        },
        "user_queryLoginName": {
            "code": "user-00002",
            "url": "http://zt-mall.go189.cn/zt-mall/user/queryLoginName"
        },
        "goods_salesList": {
            "code": "goods-00003",
            "url": "http://zt-mall.go189.cn/zt-mall/goods/salesList"
        },
        "number_getFamilyNumList": {
            "code": "number-00007",
            "url": "http://zt-mall.go189.cn/zt-mall/number/getFamilyNumList"
        },
        "number_saveNetWorkInfo": {
            "code": "number-00001",
            "url": "http://zt-mall.go189.cn/zt-mall/number/saveNetWorkInfo"
        },
        "order_fuKaSubmit": {
            "code": "order-00002",
            "url": "http://zt-mall.go189.cn/zt-mall/order/fuKaSubmit"
        },
        "pcorder_recordRecommInfo": {
            "code": "pcorder-0004",
            "url": "http://zt-mall.go189.cn/zt-mall/pcorder/recordRecommInfo"
        },
        "order_cancelOrder": {
            "code": "order-00007",
            "url": "http://zt-mall.go189.cn/zt-mall/order/cancelOrder"
        },
        "goods_queryConditionList": {
            "code": "goods-00001",
            "url": "http://zt-mall.go189.cn/zt-mall/goods/queryConditionList"
        },
        "pcorder_saveOrder": {
            "code": "pcorder-0001",
            "url": "http://zt-mall.go189.cn/zt-mall/pcorder/saveOrder"
        },
        "order_orderAfterSales": {
            "code": "order-000011",
            "url": "http://zt-mall.go189.cn/zt-mall/order/orderAfterSales"
        },
        "order_queryLoveNumberList": {
            "code": "order-00014",
            "url": "http://zt-mall.go189.cn/zt-mall/order/queryLoveNumberList"
        },
        "oldUser_queryOldUser": {
            "code": "oldUser-00002",
            "url": "http://zt-mall.go189.cn/zt-mall/oldUser/queryOldUser"
        },
        "discount_queryEffectiveInfo": {
            "code": "discount-00002",
            "url": "http://zt-mall.go189.cn/zt-mall/discount/queryEffectiveInfo"
        },
        "order_countFee": {
            "code": "order-00001",
            "url": "http://zt-mall.go189.cn/zt-mall/order/countFee"
        },
        "order_saveOrder": {
            "code": "order-00003",
            "url": "http://zt-mall.go189.cn/zt-mall/order/saveOrder"
        },
        "order_saveXuYueOrder": {
            "code": "order-00023",
            "url": "http://zt-mall.go189.cn/zt-mall/welcome/order/saveXuYueOrder"
        },
        "user_getNearly50Numbers": {
            "code": "user-00004",
            "url": "http://zt-mall.go189.cn/zt-mall/user/getNearly50Numbers"
        },
        "goods_checkWhiteList": {
            "code": "goods-00005",
            "url": "http://zt-mall.go189.cn/zt-mall/goods/checkWhiteList"
        },
        "pcorder_queryOrderDetail": {
            "code": "pcorder-0002",
            "url": "http://zt-mall.go189.cn/zt-mall/pcorder/queryOrderDetail"
        },
        "order_orderLogisticsTrack": {
            "code": "order-00012",
            "url": "http://zt-mall.go189.cn/zt-mall/order/orderLogisticsTrack"
        },
        "user_getAmountOfAccess": {
            "code": "user-00005",
            "url": "http://zt-mall.go189.cn/zt-mall/user/getAmountOfAccess"
        },
        "order_saveZWOrder": {
            "code": "order-00009",
            "url": "http://zt-mall.go189.cn/zt-mall/order/saveZWOrder"
        },
        "number_queryFamilyNumList": {
            "code": "number-00006",
            "url": "http://zt-mall.go189.cn/zt-mall/number/queryFamilyNumList"
        },
        "number_queryNetWorkInfo": {
            "code": "number-00002",
            "url": "http://zt-mall.go189.cn/zt-mall/number/queryNetWorkInfo"
        },
        "goods_queryOrderList": {
            "code": "goods-00007",
            "url": "http://zt-mall.go189.cn/zt-mall/goods/queryOrderList"
        },
        "order_orderEvaluation": {
            "code": "order-000010",
            "url": "http://zt-mall.go189.cn/zt-mall/order/orderEvaluation"
        },
        "goods_queryGoodsList": {
            "code": "goods-00006",
            "url": "http://zt-mall.go189.cn/zt-mall/goods/queryGoodsList"
        },
        "user_queryuserdetail": {
            "code": "user-00003",
            "url": "http://zt-mall.go189.cn/zt-mall/user/queryuserdetail"
        },
        "goods_queryGoodsAgreement": {
            "code": "goods-00002",
            "url": "http://zt-mall.go189.cn/zt-mall/goods/queryGoodsAgreement"
        },
        "goods_queryGoodsDetail": {
            "code": "goods-00004",
            "url": "http://zt-mall.go189.cn/zt-mall/goods/queryGoodsDetail"
        },
        "discount_queryRedEnvelope": {
            "code": "discount-00006",
            "url": "http://zt-mall.go189.cn/zt-mall/discount/queryRedEnvelope"
        },
        "order_queryOrderList": {
            "code": "order-00005",
            "url": "http://zt-mall.go189.cn/zt-mall/order/queryOrderList"
        },
        "order_getMoney": {
            "code": "order-00013",
            "url": "http://zt-mall.go189.cn/zt-mall/order/getMoney"
        },
        "order_queryOrderDetail": {
            "code": "order-00006",
            "url": "http://zt-mall.go189.cn/zt-mall/order/queryOrderDetail"
        },
        "oldUser_queryOldGoods": {
            "code": "oldUser-00003",
            "url": "http://zt-mall.go189.cn/zt-mall/oldUser/queryOldGoods"
        },
        "user_queryNumberByIdentity": {
            "code": "user-00001",
            "url": "http://zt-mall.go189.cn/zt-mall/user/queryNumberByIdentity"
        }
    }
}
window.FIX_SIX_ZT_LOGIN = {
    "keys": {
        "zt-login_login_autoRecog": "authentication_autoRecog",
        "zt-login_login_innerAccount": "authentication_innerAccount",
        "zt-login_login_offline": "authentication_offline",
        "zt-login_login_refresh": "authentication_refresh",
        "zt-login_login_dynamic": "authentication_dynamic",
        "zt-login_login_vertificateCode": "authentication_vertificateCode"
    },
    "vals": {
        "authentication_dynamic": {
            "code": "login-00002",
            "url": "http://zt-login.go189.cn/zt-login/authentication/dynamic"
        },
        "authentication_autoRecog": {
            "code": "login-00006",
            "url": "http://zt-login.go189.cn/zt-login/authentication/autoRecog"
        },
        "authentication_refresh": {
            "code": "login-00004",
            "url": "http://zt-login.go189.cn/zt-login/authentication/refresh"
        },
        "authentication_offline": {
            "code": "login-00005",
            "url": "http://zt-login.go189.cn/zt-login/authentication/offline"
        },
        "authentication_innerAccount": {
            "code": "login-00001",
            "url": "http://zt-login.go189.cn/zt-login/authentication/innerAccount"
        },
        "authentication_vertificateCode": {
            "code": "login-00003",
            "url": "http://zt-login.go189.cn/zt-login/authentication/vertificateCode"
        }
    }
};
window.FIX_SIX_ZT_CONFIG = {
    "keys": {
        "ZTFLOWORDER_config_comm": "config_comm2",
        "ZTCHANNEL-MAIN_config_comm": "config_comm",
        "ZTCHANNEL-MAIN_config_historyAct": "config_historyAct",
        "ZTCHANNEL-MAIN_config_clickActi": "config_clickActi"
    },
    "vals": {
        "config_comm2": {
            "code": "config-00001",
            "url": "http://zt-config.go189.cn/zt-config/config/comm"
        },
        "config_historyAct": {
            "code": "config-00003",
            "url": "http://zt-config.go189.cn/zt-config/config/historyAct"
        },
        "config_clickActi": {
            "code": "config-00002",
            "url": "http://zt-config.go189.cn/zt-config/config/clickActi"
        },
        "config_comm": {
            "code": "config-00001",
            "url": "http://zt-config.go189.cn/zt-config/config/comm"
        }
    }
};
window.FIX_SIX_ZT_BUSINESS = {
    "keys": {
        "jszt_rest_chinavnet": "rest_chinavnet",
        "jszt_llzq_orderPackage": "llzq_orderPackage",
        "jszt_llzq_orderPackage": "stores_messagepvrecord",
        "jszt_ipauth_get_tysh_uam": "ipauth_get_tysh_uam",
        "jszt_flowMarket_flowSuperMarketloginZt": "flowMarket_flowSuperMarketloginZt",
        "jszt_stores_medalOfWall": "stores_medalOfWall",
        "ZTFLOWORDER_newFlowProduct_queryRecommendList": "newFlowProduct_queryRecommendList",
        "ZTFLOWORDER_buscon_doSearchMyBusiness": "buscon_doSearchMyBusiness",
        "ZTFLOWORDER_boardOnDemand_checkUserStatus": "boardOnDemand_checkUserStatus",
        "ZTFLOWORDER_flowDisplay_showFlowDisplay": "flowDisplay_showFlowDisplay",
        "jszt_rest_faultReporting": "rest_faultReporting",
        "ZTFLOWORDER_rest_searchCashFlowPurchaseOrderList": "rest_searchCashFlowPurchaseOrderList",
        "jszt_braodband_getNetInfoByLoad": "braodband_getNetInfoByLoad",
        "jszt_rest_sendsharemsg": "rest_sendsharemsg",
        "ZTMALLREST_prodOffer_getProdOfferString": "prodOffer_getProdOfferString",
        "ZTMALLREST_installMove_queryInstallMovePlan": "installMove_queryInstallMovePlan",
        "jszt_packageaction_checkIfreeFlow": "packageaction_checkIfreeFlow",
        "ZTMALLREST_BBSwitch_queryBroadBand": "BBSwitch_queryBroadBand",
        "ZTFLOWORDER_flowOrderOrFree_orderFlow": "flowOrderOrFree_orderFlow",
        "jszt_braodband_checkHighSpeedInfo": "braodband_checkHighSpeedInfo",
        "jszt_rest_llkpay": "rest_llkpay",
        "jszt_llzqtoken_orderWithfor4G": "llzqtoken_orderWithfor4G",
        "ZTMALLREST_broadband_getBroadBandString": "broadband_getBroadBandString",
        "jszt_rest_unsubscribepackage": "rest_unsubscribepackage",
        "jszt_ztserverauth_orderpackagemoreidsbyCAP": "ztserverauth_orderpackagemoreidsbyCAP",
        "jszt_braodband_highSpeedSubmit": "braodband_highSpeedSubmit",
        "jszt_recharge_takeNoteRecharge": "recharge_takeNoteRecharge",
        "jszt_rest_getUserInfoByNum": "rest_getUserInfoByNum",
        "jszt_rest_getareacode": "rest_getareacode",
        "ZTMALLREST_installationITV_queryBroadbandInformationByIdCard": "installationITV_queryBroadbandInformationByIdCard",
        "ZTMALLREST_preferential_minePrefe": "preferential_minePrefe",
        "jszt_stores_getorderinfobyproductid": "stores_getorderinfobyproductid",
        "jszt_rest_charge": "rest_charge",
        "jszt_rest_ordervsop": "rest_ordervsop",
        "jszt_rest_secondVerify": "rest_secondVerify",
        "jszt_recharge_queryReturnPlan": "recharge_queryReturnPlan",
        "jszt_rest_findByIsLeaf": "rest_findByIsLeaf",
        "ZTFLOWORDER_flowOrderOrFree_ordersecondconfirm": "flowOrderOrFree_ordersecondconfirm",
        "jszt_rest_getareacode2": "rest_getareacode2",
        "jszt_rest_rechargehistory": "rest_rechargehistory",
        "ZTFLOWORDER_flowSearchNotice_getNewFlowSearch": "flowSearchNotice_getNewFlowSearch",
        "jszt_braodband_checkHomeBroadband": "braodband_checkHomeBroadband",
        "ZTFLOWORDER_flowDisplay_insertFlowDisplay": "flowDisplay_insertFlowDisplay",
        "jszt_highcard_checkIsHighCard": "highcard_checkIsHighCard",
        "jszt_stores_queryOrderInfoByOrderNumAndIdCard": "stores_queryOrderInfoByOrderNumAndIdCard",
        "jszt_recharge_queryRechargeRecordByMonth": "recharge_queryRechargeRecordByMonth",
        "jszt_stores_queryOwnOrderMsgList": "stores_queryOwnOrderMsgList",
        "ZTFLOWORDER_newFlowProduct_getFlowProductList": "newFlowProduct_getFlowProductList",
        "ZTMALLREST_chooseOrderNum_getNum": "chooseOrderNum_getNum",
        "jszt_recharge_queryRechargeRecord": "recharge_queryRechargeRecord",
        "jszt_highcard_receiveRed": "highcard_receiveRed",
        "ZTMALLREST_broadbandRate_getBroadBandRateString": "broadbandRate_getBroadBandRateString",
        "ZTMALLREST_broadBandBuiness_doSearchBroadBandMessageById": "broadBandBuiness_doSearchBroadBandMessageById",
        "ZTMALLREST_orderConfirm_getOrderConfirm": "orderConfirm_getOrderConfirm",
        "jszt_braodband_checkSpeedBroad": "braodband_checkSpeedBroad",
        "jszt_stores_orderdetail": "stores_orderdetail",
        "jszt_rest_verifyUserInfoByAccNbr": "rest_verifyUserInfoByAccNbr",
        "jszt_highcard_checkIsReceiveRed": "highcard_checkIsReceiveRed",
        "jszt_rest_randomcode": "rest_randomcode",
        "jszt_rest_uploadRecommed": "rest_uploadRecommed",
        "ZTMALLREST_broadBandBuiness_searchBroadBandSaleList": "broadBandBuiness_searchBroadBandSaleList",
        "ZTFLOWORDER_newFlowProduct_getFlowRecommendProductListByTag": "newFlowProduct_getFlowRecommendProductListByTag",
        "jszt_rest_newbusiness": "rest_newbusiness",
        "jszt_rest_rechCardPay": "rest_rechCardPay",
        "jszt_rest_getLonginKDInfo": "rest_getLonginKDInfo",
        "jszt_rest_queryOrderList": "rest_queryOrderList",
        "ZTMALLREST_BBSwitch_updateBBSwitchStatus": "BBSwitch_updateBBSwitchStatus",
        "jszt_stores_queryOrderMsgList": "stores_queryOrderMsgList",
        "ZTFLOWORDER_bussPro_doSearchMyBusiness": "bussPro_doSearchMyBusiness",
        "ZTFLOWORDER_newFlowProduct_getFlowDetail": "newFlowProduct_getFlowDetail",
        "jszt_packageaction_checkIfreeNum": "packageaction_checkIfreeNum",
        "jszt_stores_highRechargeOrderSubmit": "stores_highRechargeOrderSubmit",
        "ZTMALLREST_broadBandBuiness_searchBroadBandIncreaseSpeedBuiness": "broadBandBuiness_searchBroadBandIncreaseSpeedBuiness",
        "ZTFLOWORDER_flowrest_getFlowRecomList": "flowrest_getFlowRecomList",
        "ZTMALLREST_broadBandBuiness_selectFreePolicyCodeCount": "broadBandBuiness_selectFreePolicyCodeCount",
        "ZTFLOWORDER_newFlowProduct_getFlowProductList": "newFlowProduct_getFlowProductList",
        "jszt_ztserverauth_orderflowbyCAP": "ztserverauth_orderflowbyCAP",
        "ZTMALLREST_orderOf_getOrderOf": "orderOf_getOrderOf",
        "jszt_braodband_submitOrder": "braodband_submitOrder",
        "jszt_recharge_queryReturnDetails": "recharge_queryReturnDetails",
        "ZTFLOWORDER_bussPro_doSearchBussHallList": "bussPro_doSearchBussHallList",
        "jszt_braodband_highCardBroadBand": "braodband_highCardBroadBand",
        "ZTMALLREST_broadBandBuiness_selectUserBroadAccNbr": "broadBandBuiness_selectUserBroadAccNbr",
        "ZTFLOWORDER_flowrest_getFocusPic": "flowrest_getFocusPic",
        "ZTFLOWORDER_newFlowProduct_getAllFlowProductList": "newFlowProduct_getAllFlowProductList",
        "ZTFLOWORDER_bussPro_doSearchbussByproId": "bussPro_doSearchbussByproId",
        "jszt_llzq_flowpromotionorder": "llzq_flowpromotionorder",
        "jszt_braodband_dsHighCardBroadBand": "braodband_dsHighCardBroadBand",
        "ZTFLOWORDER_bussPro_bussOrder": "bussPro_bussOrder",
        "ZTFLOWORDER_BusinessOrder_BusinessOrderServer": "BusinessOrder_BusinessOrderServer",
        "jszt_rest_getLonginPhoneInfo": "rest_getLonginPhoneInfo",
        "ZTMALLREST_broadBandBuiness_orderFreeBroadBandLabel": "broadBandBuiness_orderFreeBroadBandLabel",
        "jszt_topSpeed_checkFree": "topSpeed_checkFree",
        "ZTFLOWORDER_bussPro_doSearchbussListByBussType": "bussPro_doSearchbussListByBussType",
        "ZTMALLREST_broadBandBuiness_doSearchBroadBandMessageByAccNbr": "broadBandBuiness_doSearchBroadBandMessageByAccNbr",
        "jszt_rest_accnbrcurbill": "rest_accnbrcurbill",
        "jszt_llzqtoken_orderPackage": "llzqtoken_orderPackage",
        "jszt_stores_getorderinfobyordernumber": "stores_getorderinfobyordernumber",
        "ZTMALLREST_orderSubmitIfree_getOrderSubmit": "orderSubmitIfree_getOrderSubmit",
        "jszt_rest_narrowband": "rest_narrowband",
        "jszt_stores_orderMsgChange": "stores_orderMsgChange",
        "jszt_stores_wuliudetail": "stores_wuliudetail",
        "jszt_ztauth_validateAuthCode": "ztauth_validateAuthCode",
        "jszt_secureGuards_checkParentsAccNum":"secureGuards_checkParentsAccNum",//安心宝start
        "jszt_secureGuards_checkChildAccNum":"secureGuards_checkChildAccNum",
        "jszt_secureGuards_binding":"secureGuards_binding",
        "jszt_secureGuards_queryBindingNbrTime":"secureGuards_queryBindingNbrTime",
        "jszt_secureGuards_searchBangdingState":"secureGuards_searchBangdingState",
        "jszt_secureGuards_queryOpenState":"secureGuards_queryOpenState",
        "jszt_secureGuards_setSafetyProtection":"secureGuards_setSafetyProtection",
        "jszt_secureGuards_setForbiddenWebTime":"secureGuards_setForbiddenWebTime",
        "jszt_secureGuards_queryInterceptLog":"secureGuards_queryInterceptLog",
        "jszt_secureGuards_queryBlockInternetTime":"secureGuards_queryBlockInternetTime",
        "jszt_secureGuards_setForbiddenWebTimeNew":"secureGuards_setForbiddenWebTimeNew",//安心宝end
    	"ZT-PAY_xuYuePay_wapXuYuePay":"xuYuePay_wapXuYuePay", // 修复宽带续约支付宝支付接口
    	"jszt_rest_getDynamicPwd":"rest_getDynamicPwd", // 积分兑换的短信发送及验证接口千万级迁移映射
    	"jszt_rest_loginByDynamicPwd":"rest_loginByDynamicPwd"
    },
    "vals": {
        "rest_chinavnet": {
            "code": "jszt-00070",
            "url": "http://zt-business.go189.cn/zt-business/rest/chinavne"
        },
        "llzq_orderPackage": {
            "code":"jszt-00077",
            "url":"http://zt-business.go189.cn/zt-business/llzq/orderPackage"
        },
        "stores_messagepvrecord": {
            "code":"stores-00003",
            "url":"http://zt-business.go189.cn/zt-business/stores/messagepvrecord"
        },
        "ipauth_get_tysh_uam": {
            "code": "jszt-00075",
            "url": "http://zt-business.go189.cn/zt-business/ipauth/get_tysh_uam"
        },
        "flowMarket_flowSuperMarketloginZt": {
            "code": "jszt-00075",
            "url": "http://zt-business.go189.cn/zt-business/flowMarket/flowSuperMarketloginZt"
        },
        "stores_medalOfWall": {
            "code": "jszt-00074",
            "url": "http://zt-business.go189.cn/zt-business/stores/medalOfWall"
        },
        "newFlowProduct_queryRecommendList": {
            "code": "flow-00029",
            "url": "http://zt-business.go189.cn/zt-business/newFlowProduct/queryRecommendList"
        },
        "buscon_doSearchMyBusiness": {
            "code": "flow-00009",
            "url": "http://zt-business.go189.cn/zt-business/bussPro/doSearchMyBusiness"
        },
        "boardOnDemand_checkUserStatus": {
            "code": "flow-00025",
            "url": "http://zt-business.go189.cn/zt-business/boardOnDemand/checkUserStatus"
        },
        "ztauth_validateAuthCode": {
        	"code": "jszt-00065",
            "url": "http://zt-business.go189.cn/zt-business/ztauth/validateAuthCode"
        },
        "rest_findByIsLeaf": {
            "code": "jszt-00035",
            "url": "http://zt-business.go189.cn/zt-business/rest/findByIsLeaf"
        },
        "recharge_queryRechargeRecord": {
            "code": "jszt-00055",
            "url": "http://zt-business.go189.cn/zt-business/recharge/queryRechargeRecord"
        },
        "bussPro_doSearchbussByproId": {
            "code": "flow-00011",
            "url": "http://zt-business.go189.cn/zt-business/bussPro/doSearchbussByproId"
        },
        "recharge_queryRechargeRecordByMonth": {
            "code": "jszt-00059",
            "url": "http://zt-business.go189.cn/zt-business/recharge/queryRechargeRecordByMonth"
        },
        "recharge_takeNoteRecharge": {
            "code": "jszt-00058",
            "url": "http://zt-business.go189.cn/zt-business/recharge/takeNoteRecharge"
        },
        "orderOf_getOrderOf": {
            "code": "mall-00009",
            "url": "http://zt-business.go189.cn/zt-business/orderOf/getOrderOf"
        },
        "rest_accnbrcurbill": {
            "code": "jszt-00012",
            "url": "http://zt-business.go189.cn/zt-business/rest/accnbrcurbill"
        },
        "braodband_highCardBroadBand": {
            "code": "jszt-00007",
            "url": "http://zt-business.go189.cn/zt-business/braodband/highCardBroadBand"
        },
        "braodband_submitOrder": {
            "code": "jszt-00004",
            "url": "http://zt-business.go189.cn/zt-business/braodband/submitOrder"
        },
        "rest_llkpay": {
            "code": "jszt-00043",
            "url": "http://zt-business.go189.cn/zt-business/rest/llkpay"
        },
        "stores_queryOwnOrderMsgList": {
            "code": "jszt-00022",
            "url": "http://zt-business.go189.cn/zt-business/stores/queryOwnOrderMsgList"
        },
        "rest_verifyUserInfoByAccNbr": {
            "code": "jszt-00029",
            "url": "http://zt-business.go189.cn/zt-business/rest/verifyUserInfoByAccNbr"
        },
        "bussPro_doSearchMyBusiness": {
            "code": "flow-00009",
            "url": "http://zt-business.go189.cn/zt-business/bussPro/doSearchMyBusiness"
        },
        "broadBandBuiness_doSearchBroadBandMessageById": {
            "code": "mall-00001",
            "url": "http://zt-business.go189.cn/zt-business/broadBandBuiness/doSearchBroadBandMessageById"
        },
        "topSpeed_checkFree": {
            "code": "jszt-00014",
            "url": "http://zt-business.go189.cn/zt-business/topSpeed/checkFree"
        },
        "chooseOrderNum_getNum": {
            "code": "mall-00013",
            "url": "http://zt-business.go189.cn/zt-business/chooseOrderNum/getNum"
        },
        "rest_getLonginKDInfo": {
            "code": "jszt-00011",
            "url": "http://zt-business.go189.cn/zt-business/rest/getLonginKDInfo"
        },
        "rest_searchCashFlowPurchaseOrderList": {
            "code": "flow-00005",
            "url": "http://zt-business.go189.cn/zt-business/rest/searchCashFlowPurchaseOrderList"
        },
        "rest_rechargehistory": {
            "code": "jszt-00045",
            "url": "http://zt-business.go189.cn/zt-business/rest/rechargehistory"
        },
        "installMove_queryInstallMovePlan": {
            "code": "mall-00012",
            "url": "http://zt-business.go189.cn/zt-business/installMove/queryInstallMovePlan"
        },
        "ztserverauth_orderpackagemoreidsbyCAP": {
            "code": "jszt-00053",
            "url": "http://zt-business.go189.cn/zt-business/ztserverauth/orderpackagemoreidsbyCAP"
        },
        "rest_uploadRecommed": {
            "code": "jszt-00047",
            "url": "http://zt-business.go189.cn/zt-business/rest/uploadRecommed"
        },
        "flowOrderOrFree_orderFlow": {
            "code": "flow-00013",
            "url": "http://zt-business.go189.cn/zt-business/flowOrderOrFree/orderFlow"
        },
        "flowDisplay_showFlowDisplay": {
            "code": "flow-00014",
            "url": "http://zt-business.go189.cn/zt-business/flowDisplay/showFlowDisplay"
        },
        "rest_rechCardPay": {
            "code": "jszt-00044",
            "url": "http://zt-business.go189.cn/zt-business/rest/rechCardPay"
        },
        "newFlowProduct_getFlowProductList": {
            "code": "flow-00004",
            "url": "http://zt-business.go189.cn/zt-business/newFlowProduct/getFlowProductList"
        },
        "rest_getareacode": {
            "code": "jszt-00042",
            "url": "http://zt-business.go189.cn/zt-business/rest/getareacode"
        },
        "highcard_checkIsReceiveRed": {
            "code": "jszt-00016",
            "url": "http://zt-business.go189.cn/zt-business/highcard/checkIsReceiveRed"
        },
        "stores_orderdetail": {
            "code": "jszt-00026",
            "url": "http://zt-business.go189.cn/zt-business/stores/orderdetail"
        },
        "orderSubmitIfree_getOrderSubmit": {
            "code": "mall-00018",
            "url": "http://zt-business.go189.cn/zt-business/orderSubmitIfree/getOrderSubmit"
        },
        "packageaction_checkIfreeFlow": {
            "code": "jszt-00019",
            "url": "http://zt-business.go189.cn/zt-business/packageaction/checkIfreeFlow"
        },
        "orderConfirm_getOrderConfirm": {
            "code": "mall-00017",
            "url": "http://zt-business.go189.cn/zt-business/orderConfirm/getOrderConfirm"
        },
        "flowOrderOrFree_ordersecondconfirm": {
            "code": "flow-00012",
            "url": "http://zt-business.go189.cn/zt-business/flowOrderOrFree/ordersecondconfirm"
        },
        "ztserverauth_orderflowbyCAP": {
            "code": "jszt-00054",
            "url": "http://zt-business.go189.cn/zt-business/ztserverauth/orderflowbyCAP"
        },
        "rest_queryOrderList": {
            "code": "jszt-00036",
            "url": "http://zt-business.go189.cn/zt-business/rest/queryOrderList"
        },
        "llzqtoken_orderWithfor4G": {
            "code": "jszt-00051",
            "url": "http://zt-business.go189.cn/zt-business/llzqtoken/orderWithfor4G"
        },
        "flowrest_getFlowRecomList": {
            "code": "flow-00006",
            "url": "http://zt-business.go189.cn/zt-business/flowrest/getFlowRecomList"
        },
        "BBSwitch_queryBroadBand": {
            "code": "mall-00010",
            "url": "http://zt-business.go189.cn/zt-business/BBSwitch/queryBroadBand"
        },
        "bussPro_doSearchbussListByBussType": {
            "code": "flow-00010",
            "url": "http://zt-business.go189.cn/zt-business/bussPro/doSearchbussListByBussType"
        },
        "braodband_checkHighSpeedInfo": {
            "code": "jszt-00005",
            "url": "http://zt-business.go189.cn/zt-business/braodband/checkHighSpeedInfo"
        },
        "BusinessOrder_BusinessOrderServer": {
            "code": "flow-00016",
            "url": "http://zt-business.go189.cn/zt-business/BusinessOrder/BusinessOrderServer"
        },
        "stores_getorderinfobyproductid": {
            "code": "jszt-00025",
            "url": "http://zt-business.go189.cn/zt-business/stores/getorderinfobyproductid"
        },
        "stores_queryOrderInfoByOrderNumAndIdCard": {
            "code": "jszt-00028",
            "url": "http://zt-business.go189.cn/zt-business/stores/queryOrderInfoByOrderNumAndIdCard"
        },
        "packageaction_checkIfreeNum": {
            "code": "jszt-00020",
            "url": "http://zt-business.go189.cn/zt-business/packageaction/checkIfreeNum"
        },
        "rest_narrowband": {
            "code": "jszt-00038",
            "url": "http://zt-business.go189.cn/zt-business/rest/narrowband"
        },
        "broadBandBuiness_searchBroadBandIncreaseSpeedBuiness": {
            "code": "mall-00004",
            "url": "http://zt-business.go189.cn/zt-business/broadBandBuiness/searchBroadBandIncreaseSpeedBuiness"
        },
        "bussPro_doSearchBussHallList": {
            "code": "flow-00008",
            "url": "http://zt-business.go189.cn/zt-business/bussPro/doSearchBussHallList"
        },
        "rest_unsubscribepackage": {
            "code": "jszt-00033",
            "url": "http://zt-business.go189.cn/zt-business/rest/unsubscribepackage"
        },
        "broadBandBuiness_selectFreePolicyCodeCount": {
            "code": "mall-00007",
            "url": "http://zt-business.go189.cn/zt-business/broadBandBuiness/selectFreePolicyCodeCount"
        },
        "broadband_getBroadBandString": {
            "code": "mall-00016",
            "url": "http://zt-business.go189.cn/zt-business/broadband/getBroadBandString"
        },
        "highcard_checkIsHighCard": {
            "code": "jszt-00015",
            "url": "http://zt-business.go189.cn/zt-business/highcard/checkIsHighCard"
        },
        "braodband_dsHighCardBroadBand": {
            "code": "jszt-00008",
            "url": "http://zt-business.go189.cn/zt-business/braodband/dsHighCardBroadBand"
        },
        "newFlowProduct_getAllFlowProductList": {
            "code": "flow-00001",
            "url": "http://zt-business.go189.cn/zt-business/newFlowProduct/getAllFlowProductList"
        },
        "bussPro_bussOrder": {
            "code": "flow-00017",
            "url": "http://zt-business.go189.cn/zt-business/bussPro/bussOrder"
        },
        "broadBandBuiness_selectUserBroadAccNbr": {
            "code": "mall-00003",
            "url": "http://zt-business.go189.cn/zt-business/broadBandBuiness/selectUserBroadAccNbr"
        },
        "stores_getorderinfobyordernumber": {
            "code": "jszt-00027",
            "url": "http://zt-business.go189.cn/zt-business/stores/getorderinfobyordernumber"
        },
        "broadBandBuiness_doSearchBroadBandMessageByAccNbr": {
            "code": "mall-00002",
            "url": "http://zt-business.go189.cn/zt-business/broadBandBuiness/doSearchBroadBandMessageByAccNbr"
        },
        "rest_getLonginPhoneInfo": {
            "code": "jszt-00010",
            "url": "http://zt-business.go189.cn/zt-business/rest/getLonginPhoneInfo"
        },
        "BBSwitch_updateBBSwitchStatus": {
            "code": "mall-00011",
            "url": "http://zt-business.go189.cn/zt-business/BBSwitch/updateBBSwitchStatus"
        },
        "recharge_queryReturnDetails": {
            "code": "jszt-00057",
            "url": "http://zt-business.go189.cn/zt-business/recharge/queryReturnDetails"
        },
        "braodband_highSpeedSubmit": {
            "code": "jszt-00006",
            "url": "http://zt-business.go189.cn/zt-business/braodband/highSpeedSubmit"
        },
        "flowrest_getFocusPic": {
            "code": "flow-00007",
            "url": "http://zt-business.go189.cn/zt-business/flowrest/getFocusPic"
        },
        "stores_queryOrderMsgList": {
            "code": "jszt-00021",
            "url": "http://zt-business.go189.cn/zt-business/stores/queryOrderMsgList"
        },
        "rest_secondVerify": {
            "code": "jszt-00037",
            "url": "http://zt-business.go189.cn/zt-business/rest/secondVerify"
        },
        "rest_randomcode": {
            "code": "jszt-00030",
            "url": "http://zt-business.go189.cn/zt-business/rest/randomcode"
        },
        "broadbandRate_getBroadBandRateString": {
            "code": "mall-00019",
            "url": "http://zt-business.go189.cn/zt-business/broadbandRate/getBroadBandRateString"
        },
        "rest_getUserInfoByNum": {
            "code": "jszt-00049",
            "url": "http://zt-business.go189.cn/zt-business/rest/getUserInfoByNum"
        },
        "newFlowProduct_getFlowRecommendProductListByTag": {
            "code": "flow-00002",
            "url": "http://zt-business.go189.cn/zt-business/newFlowProduct/getFlowRecommendProductListByTag"
        },
        "llzq_flowpromotionorder": {
            "code": "jszt-00052",
            "url": "http://zt-business.go189.cn/zt-business/llzq/flowpromotionorder"
        },
        "rest_getareacode2": {
            "code": "jszt-00013",
            "url": "http://zt-business.go189.cn/zt-business/rest/getareacode2"
        },
        "recharge_queryReturnPlan": {
            "code": "jszt-00056",
            "url": "http://zt-business.go189.cn/zt-business/recharge/queryReturnPlan"
        },
        "flowSearchNotice_getNewFlowSearch": {
            "code": "flow-00019",
            "url": "http://zt-business.go189.cn/zt-business/flowSearchNotice/getNewFlowSearch"
        },
        "preferential_minePrefe": {
            "code": "mall-00015",
            "url": "http://zt-business.go189.cn/zt-business/preferential/minePrefe"
        },
        "broadBandBuiness_orderFreeBroadBandLabel": {
            "code": "mall-00006",
            "url": "http://zt-business.go189.cn/zt-business/broadBandBuiness/orderFreeBroadBandLabel"
        },
        "stores_orderMsgChange": {
            "code": "jszt-00023",
            "url": "http://zt-business.go189.cn/zt-business/stores/orderMsgChange"
        },
        "prodOffer_getProdOfferString": {
            "code": "mall-00014",
            "url": "http://zt-business.go189.cn/zt-business/prodOffer/getProdOfferString"
        },
        "braodband_getNetInfoByLoad": {
            "code": "jszt-00003",
            "url": "http://zt-business.go189.cn/zt-business/braodband/getNetInfoByLoad"
        },
        "broadBandBuiness_searchBroadBandSaleList": {
            "code": "mall-00005",
            "url": "http://zt-business.go189.cn/zt-business/broadBandBuiness/searchBroadBandSaleList"
        },
        "stores_wuliudetail": {
            "code": "jszt-00024",
            "url": "http://zt-business.go189.cn/zt-business/stores/wuliudetail"
        },
        "rest_sendsharemsg": {
            "code": "jszt-00048",
            "url": "http://zt-business.go189.cn/zt-business/rest/sendsharemsg"
        },
        "installationITV_queryBroadbandInformationByIdCard": {
            "code": "mall-00008",
            "url": "http://zt-business.go189.cn/zt-business/installationITV/queryBroadbandInformationByIdCard"
        },
        "rest_ordervsop": {
            "code": "jszt-00034",
            "url": "http://zt-business.go189.cn/zt-business/rest/ordervsop"
        },
        "rest_newbusiness": {
            "code": "jszt-00040",
            "url": "http://zt-business.go189.cn/zt-business/rest/newbusiness"
        },
        "llzqtoken_orderPackage": {
            "code": "jszt-00050",
            "url": "http://zt-business.go189.cn/zt-business/llzqtoken/orderPackage"
        },
        "newFlowProduct_getFlowDetail": {
            "code": "flow-00003",
            "url": "http://zt-business.go189.cn/zt-business/newFlowProduct/getFlowDetail"
        },
        "highcard_receiveRed": {
            "code": "jszt-00017",
            "url": "http://zt-business.go189.cn/zt-business/highcard/receiveRed"
        },
        "braodband_checkHomeBroadband": {
            "code": "jszt-00001",
            "url": "http://zt-business.go189.cn/zt-business/braodband/checkHomeBroadband"
        },
        "braodband_checkSpeedBroad": {
            "code": "jszt-00002",
            "url": "http://zt-business.go189.cn/zt-business/braodband/checkSpeedBroad"
        },
        "rest_charge": {
            "code": "jszt-00009",
            "url": "http://zt-business.go189.cn/zt-business/rest/charge"
        },
        "flowDisplay_insertFlowDisplay": {
            "code": "flow-00015",
            "url": "http://zt-business.go189.cn/zt-business/flowDisplay/insertFlowDisplay"
        },
        "rest_faultReporting": {
            "code": "jszt-00031",
            "url": "http://zt-business.go189.cn/zt-business/rest/faultReporting"
        },
        "stores_highRechargeOrderSubmit": {
            "code": "jszt-00018",
            "url": "http://zt-business.go189.cn/zt-business/stores/highRechargeOrderSubmit"
        },
        "secureGuards_checkParentsAccNum": {//安心宝start
            "code": "secure-00001",
            "url": "http://zt-business.go189.cn/zt-business/welcome/secureGuards/checkParentsAccNum"
        },
        "secureGuards_checkChildAccNum": {
            "code": "secure-00002",
            "url": "http://zt-business.go189.cn/zt-business/welcome/secureGuards/checkChildAccNum"
        },
        "secureGuards_binding": {
            "code": "secure-00003",
            "url": "http://zt-business.go189.cn/zt-business/welcome/secureGuards/binding"
        },
        "secureGuards_queryBindingNbrTime": {
            "code": "secure-00004",
            "url": "http://zt-business.go189.cn/zt-business/welcome/secureGuards/queryBindingNbrTime"
        },
        "secureGuards_searchBangdingState": {
            "code": "secure-00005",
            "url": "http://zt-business.go189.cn/zt-business/welcome/secureGuards/searchBangdingState"
        },
        "secureGuards_queryOpenState": {
            "code": "secure-00006",
            "url": "http://zt-business.go189.cn/zt-business/welcome/secureGuards/queryOpenState"
        },
        "secureGuards_setSafetyProtection": {
            "code": "secure-00007",
            "url": "http://zt-business.go189.cn/zt-business/welcome/secureGuards/setSafetyProtection"
        },
        "secureGuards_setForbiddenWebTime": {
            "code": "secure-00008",
            "url": "http://zt-business.go189.cn/zt-business/welcome/secureGuards/setForbiddenWebTime"
        },
        "secureGuards_queryInterceptLog": {
            "code": "secure-00009",
            "url": "http://zt-business.go189.cn/zt-business/welcome/secureGuards/queryInterceptLog"
        },
        "secureGuards_queryBlockInternetTime": {
            "code": "secure-000010",
            "url": "http://zt-business.go189.cn/zt-business/welcome/secureGuards/queryBlockInternetTime"
        },
        "secureGuards_setForbiddenWebTimeNew": {//安心宝end
            "code": "secure-000011",
            "url": "http://zt-business.go189.cn/zt-business/welcome/secureGuards/setForbiddenWebTimeNew"
        },
        "xuYuePay_wapXuYuePay": { // 修复宽带续约支付宝支付接口
            "code": "pay-00013",
            "url": "http://zt-pay.go189.cn/zt-pay/xuYuePay/wapXuYuePay"
        },
        "rest_getDynamicPwd": { // 积分兑换的短信发送及验证接口千万级迁移映射
            "code": "jszt-00068",
            "url": "http://zt-business.go189.cn/zt-business/welcome/rest/getDynamicPwd"
        },
        "rest_loginByDynamicPwd": {
            "code": "jszt-00069",
            "url": "http://zt-business.go189.cn/zt-business/welcome/rest/loginByDynamicPwd"
        }
    }
};
window.FIX_SIX_ZT_APP = {
    "keys": {
        "ZTCHANNEL-MAIN_config_getSlaveFlag": "config_getSlaveFlag",
        "jszt_oneKeyDetection_privilegeFreeFlow": "oneKeyDetection_privilegeFreeFlow",
        "jszt_oneKeyDetection_detection3gUp4g": "oneKeyDetection_detection3gUp4g",
        "ZTFLOWORDER_bootAnimation_downLoadBootImage": "welcome_downLoadBootImage",
        "ZTCHANNEL-MAIN_config_advice": "config_advice",
        "ZTMALLREST_message_queryPersonalMessageInfo": "message_queryPersonalMessageInfo",
        "ZTMALLREST_announcement_queryAnnouncementInfo": "announcement_queryAnnouncementInfo",
        "ZTCHANNEL-MAIN_config_checkMaster": "config_checkMaster",
        "jszt_rest_queryApkVersion": "version_queryApkVersion",
        "ZTMALLREST_message_queryPersonMessageList": "message_queryPersonMessageList",
        "ZTFLOWORDER_bootAnimation_showBootAnimation": "welcome_showBootAnimation",
        "ZTMALLREST_message_getUnReadMessage": "message_getUnReadMessage",
        "ZTMALLREST_announcement_queryAnnouncementList": "announcement_queryAnnouncementList"
    },
    "vals": {
        "version_queryApkVersion": {
            "code": "base-00003",
            "url": "http://zt-app.go189.cn/zt-app/version/queryApkVersion"
        },
        "config_advice": {
            "code": "base-00009",
            "url": "http://zt-app.go189.cn/zt-app/config/advice"
        },
        "announcement_queryAnnouncementInfo": {
            "code": "base-00001",
            "url": "http://zt-app.go189.cn/zt-app/announcement/queryAnnouncementInfo"
        },
        "welcome_showBootAnimation": {
            "code": "base-00004",
            "url": "http://zt-app.go189.cn/zt-app/welcome/showBootAnimation"
        },
        "message_queryPersonMessageList": {
            "code": "base-00006",
            "url": "http://zt-app.go189.cn/zt-app/message/queryPersonMessageList"
        },
        "message_queryPersonalMessageInfo": {
            "code": "base-00007",
            "url": "http://zt-app.go189.cn/zt-app/message/queryPersonalMessageInfo"
        },
        "announcement_queryAnnouncementList": {
            "code": "base-00002",
            "url": "http://zt-app.go189.cn/zt-app/announcement/queryAnnouncementList"
        },
        "config_getSlaveFlag": {
            "code": "base-00010",
            "url": "http://zt-app.go189.cn/zt-app/config/getSlaveFlag"
        },
        "config_checkMaster": {
            "code": "base-00011",
            "url": "http://zt-app.go189.cn/zt-app/config/checkMaster"
        },
        "message_getUnReadMessage": {
            "code": "base-00008",
            "url": "http://zt-app.go189.cn/zt-app/message/getUnReadMessage"
        },
        "oneKeyDetection_privilegeFreeFlow": {
            "code": "base-00013",
            "url": "http://zt-app.go189.cn/zt-app/oneKeyDetection/privilegeFreeFlow"
        },
        "oneKeyDetection_detection3gUp4g": {
            "code": "base-00012",
            "url": "http://zt-app.go189.cn/zt-app/oneKeyDetection/detection3gUp4g"
        },
        "welcome_downLoadBootImage": {
            "code": "base-00005",
            "url": "http://zt-app.go189.cn/zt-app/welcome/downLoadBootImage"
        }
    }
};
window.FIX_SIX_ZT_APPEND = {
    "keys": {
        "jszt_ztauth_getAuthCode": "ztauth_getAuthCode",
        "ZTMALLREST_broadBandBuiness_doSearchBroadBandMessageById": "broadBandBuiness_doSearchBroadBandMessageById",
        "ZTMALLREST_installationITV_queryBroadbandInformationByIdCard": "installationITV_queryBroadbandInformationByIdCard",
        "jszt_stores_sendWeibo": "stores_sendWeibo",
    },
    "vals": {
        "ztauth_getAuthCode": {
            "code": "jszt-00060",
            "url": "http://zt-business.go189.cn/zt-business/ztauth/getAuthCode"
        },
        "broadBandBuiness_doSearchBroadBandMessageById": {
            "code": "mall-00020",
            "url": "http://zt-business.go189.cn/zt-business/broadBandBuiness/doSearchBroadBandMessageById"
        },
        "installationITV_queryBroadbandInformationByIdCard": {
            "code": "mall-00021",
            "url": "http://zt-business.go189.cn/zt-business/installationITV/queryBroadbandInformationByIdCard"
        },
        "stores_sendWeibo": {
            "code": "base-00014",
            "url": "http://zt-app.go189.cn/zt-app/stores/sendWeibo"
        }
    }
};
window.FIX_SIX_ZT_APPEND1 = {
    "keys": {
        "ZTMALLREST_broadBandBuiness_searchBroadBandIncreaseSpeedBuiness": "broadBandBuiness_searchBroadBandIncreaseSpeedBuiness",
        "jszt_promotiontoken_isOrderFreeFlow": "promotiontoken_isOrderFreeFlow",
        "ZTMALLREST_broadBandBuiness_searchBroadBandSaleList": "broadBandBuiness_searchBroadBandSaleList",
        "jszt_newuser_checkTianYiKanJia": "newuser_checkTianYiKanJia",
        "ZTMALLREST_broadbandRate_getBroadBandRateString": "broadbandRate_getBroadBandRateString",
        "jszt_itvOneclick_itvCheck": "itvOneclick_itvCheck",
        "ZTMALLREST_broadBandBuiness_orderFreeBroadBandLabel": "broadBandBuiness_orderFreeBroadBandLabel",
        "ZTMALLREST_broadBandBuiness_doSearchBroadBandMessageByAccNbr": "broadBandBuiness_doSearchBroadBandMessageByAccNbr",
        "ZTMALLREST_broadBandBuiness_selectUserBroadAccNbr": "broadBandBuiness_selectUserBroadAccNbr",
        "ZTMALLREST_broadBandBuiness_thirdPartyPayment": "broadBandBuiness_thirdPartyPayment",
        "jszt_rest_queryIntroducer": "rest_queryIntroducer",
        "jszt_rest_login2UserInfo": "rest_login2UserInfo",
        "jszt_renRenTuiJianAction_isTargetUser": "renRenTuiJianAction_isTargetUser",
        "jszt_liuliang_searchMainPackage": "liuliang_searchMainPackage",
        "jszt_rest_uploadUserInfo": "rest_uploadUserInfo",
        "jszt_rest_getGeneralFlowSearch": "rest_getGeneralFlowSearch",
        "jszt_message_uploadUserInfo": "message_uploadUserInfo",
        "jszt_newQuery_queryUserInfo": "newQuery_queryUserInfo",
        "jszt_uniformity_searchBillArrears": "uniformity_searchBillArrears",
        "ZTCHANNEL-MAIN_loop_findCustomerInformation": "loop_findCustomerInformation",
        "ZTMALLREST_broadbandInstall_getbroadBandInfo": "broadbandInstall_getbroadBandInfo",
        "zt-login_login_autoRecog": "authentication_autoRecog",
        "zt-login_login_innerAccount": "authentication_innerAccount",
        "zt-login_login_offline": "authentication_offline",
        "zt-login_login_refresh": "authentication_refresh",
        "zt-login_login_dynamic": "authentication_dynamic",
        "zt-login_login_vertificateCode": "authentication_vertificateCode",
        "jszt_uniformity_queryCloseParten": "config_queryCloseParten",
        "jszt_rest_wifiArea": "query_wifiArea",
        "jszt_SmartFamily_SmartFamily/checkContents": "query_SmartFamily/checkContents",
        "jszt_stores_getServerRealTime": "query_getServerRealTime",
        "jszt_rest_queryNetWorkByAreaCode": "config_queryNetWorkByAreaCode",
        "jszt_rest_allbrand": "query_allbrand",
        "jszt_rest_getwxdbyarea": "config_getwxdbyarea",
        "jszt_uniformity_searchCurrAcuReqWithCache": "uniformity_searchCurrAcuReqWithCache",
        "jszt_familyNetwork_homePage": "familyNetwork_homePage",
        "jszt_ztauth_getAuthCode": "ztauth_getAuthCode",
        "jszt_llroam_checkuserisguoman": "llroam_checkuserisguoman",
        "jszt_stores_broadbandredeem": "stores_broadbandredeem",
        "jszt_rest_accnbrscore": "rest_accnbrscore"

    },
    "vals": {
        "broadBandBuiness_orderFreeBroadBandLabel": {
            "code": "mall-00006",
            "url": "http://zt-business.go189.cn/zt-business/broadBandBuiness/orderFreeBroadBandLabel"
        },
        "rest_accnbrscore": {
            "code": "tempScore-00001",
            "url": "http://zt-score.go189.cn/zt-score/rest/accnbrscore"
        },
        "stores_broadbandredeem": {
            "code": "tempScore-00002",
            "url": "http://zt-score.go189.cn/zt-score/stores/broadbandredeem"
        },
        "familyNetwork_homePage": {
            "code": "base-00017",
            "url": "http://zt-app.go189.cn/zt-app/familyNetwork/homePage"
        },
        "ztauth_getAuthCode": {
            "code": "base-00016",
            "url": "http://zt-app.go189.cn/zt-app/ztauth/getAuthCode"
        },
        "llroam_checkuserisguoman": {
            "code": "base-00018",
            "url": "http://zt-app.go189.cn/zt-app/llroam/checkuserisguoman"
        },
        "uniformity_searchCurrAcuReqWithCache": {
            "code": "new-0008",
            "url": "http://zt-service.go189.cn/zt-service/uniformity/searchCurrAcuReqWithCache"
        },
        "query_SmartFamily/checkContents": {
            "code": "query-00004",
            "url": "http://zt-config.go189.cn/zt-config/query/SmartFamily/checkContents"
        },
        "config_queryNetWorkByAreaCode": {
            "code": "config-00006",
            "url": "http://zt-config.go189.cn/zt-config/config/queryNetWorkByAreaCode"
        },
        "config_queryCloseParten": {
            "code": "config-00005",
            "url": "http://zt-config.go189.cn/zt-config/config/queryCloseParten"
        },
        "query_getServerRealTime": {
            "code": "query-00003",
            "url": "http://zt-config.go189.cn/zt-config/query/getServerRealTime"
        },
        "query_allbrand": {
            "code": "query-00001",
            "url": "http://zt-config.go189.cn/zt-config/query/allbrand"
        },
        "config_getwxdbyarea": {
            "code": "config-00007",
            "url": "http://zt-config.go189.cn/zt-config/config/getwxdbyarea"
        },
        "query_wifiArea": {
            "code": "query-00002",
            "url": "http://zt-config.go189.cn/zt-config/query/wifiArea"
        },
        "authentication_dynamic": {
            "code": "login-00002",
            "url": "http://zt-login.go189.cn/zt-login/authentication/dynamic"
        },
        "authentication_autoRecog": {
            "code": "login-00006",
            "url": "http://zt-login.go189.cn/zt-login/authentication/autoRecog"
        },
        "authentication_refresh": {
            "code": "login-00004",
            "url": "http://zt-login.go189.cn/zt-login/authentication/refresh"
        },
        "authentication_offline": {
            "code": "login-00005",
            "url": "http://zt-login.go189.cn/zt-login/authentication/offline"
        },
        "authentication_innerAccount": {
            "code": "login-00001",
            "url": "http://zt-login.go189.cn/zt-login/authentication/innerAccount"
        },
        "authentication_vertificateCode": {
            "code": "login-00003",
            "url": "http://zt-login.go189.cn/zt-login/authentication/vertificateCode"
        },
        "newQuery_queryUserInfo": {
            "code": "new-0001",
            "url": "http://zt-service.go189.cn/zt-service/newQuery/queryUserInfo"
        },
        "rest_login2UserInfo": {
            "code": "rest-00026",
            "url": "http://zt-service.go189.cn/zt-service/rest/login2UserInfo"
        },
        "broadbandInstall_getbroadBandInfo": {
            "code": "new-0005",
            "url": "http://zt-service.go189.cn/zt-service/broadbandInstall/getbroadBandInfo"
        },
        "rest_queryIntroducer": {
            "code": "rest-00028",
            "url": "http://zt-service.go189.cn/zt-service/rest/queryIntroducer"
        },
        "message_uploadUserInfo": {
            "code": "new-0004",
            "url": "http://zt-service.go189.cn/zt-service/message/uploadUserInfo"
        },
        "loop_findCustomerInformation": {
            "code": "new-0003",
            "url": "http://zt-service.go189.cn/zt-service/loop/findCustomerInformation"
        },
        "rest_uploadUserInfo": {
            "code": "rest-00025",
            "url": "http://zt-service.go189.cn/zt-service/rest/uploadUserInfo"
        },
        "rest_getGeneralFlowSearch": {
            "code": "rest-00027",
            "url": "http://zt-service.go189.cn/zt-service/rest/getGeneralFlowSearch"
        },
        "uniformity_searchBillArrears": {
            "code": "new-0007",
            "url": "http://zt-service.go189.cn/zt-service/uniformity/searchBillArrears"
        },
        "renRenTuiJianAction_isTargetUser": {
            "code": "new-0002",
            "url": "http://zt-service.go189.cn/zt-service/renRenTuiJianAction/isTargetUser"
        },
        "liuliang_searchMainPackage": {
            "code": "new-0006",
            "url": "http://zt-service.go189.cn/zt-service/liuliang/searchMainPackage"
        },
        "newuser_checkTianYiKanJia": {
            "code": "jszt-00062",
            "url": "http://zt-business.go189.cn/zt-business/newuser/checkTianYiKanJia"
        },
        "broadBandBuiness_thirdPartyPayment": {
            "code": "pay-00009",
            "url": "http://zt-pay.go189.cn/zt-pay/broadBandBuiness/thirdPartyPayment"
        },
        "broadbandRate_getBroadBandRateString": {
            "code": "mall-000022",
            "url": "http://zt-business.go189.cn/zt-business/broadbandRate/getBroadBandRateString"
        },
        "broadBandBuiness_searchBroadBandSaleList": {
            "code": "mall-00005",
            "url": "http://zt-business.go189.cn/zt-business/broadBandBuiness/searchBroadBandSaleList"
        },
        "broadBandBuiness_selectUserBroadAccNbr": {
            "code": "mall-00003",
            "url": "http://zt-business.go189.cn/zt-business/broadBandBuiness/selectUserBroadAccNbr"
        },
        "itvOneclick_itvCheck": {
            "code": "jszt-00063",
            "url": "http://zt-business.go189.cn/zt-business/itvOneclick/itvCheck"
        },
        "broadBandBuiness_doSearchBroadBandMessageByAccNbr": {
            "code": "mall-00002",
            "url": "http://zt-business.go189.cn/zt-business/broadBandBuiness/doSearchBroadBandMessageByAccNbr"
        },
        "broadBandBuiness_searchBroadBandIncreaseSpeedBuiness": {
            "code": "mall-00004",
            "url": "http://zt-business.go189.cn/zt-business/broadBandBuiness/searchBroadBandIncreaseSpeedBuiness"
        },
        "promotiontoken_isOrderFreeFlow": {
            "code": "jszt-00061",
            "url": "http://zt-business.go189.cn/zt-business/promotiontoken/isOrderFreeFlow"
        }
    }
};
window.FIX_SIX_ZT_APPEND2 = {
    "keys": {
        "ZTCHANNEL-MAIN_loop_accountSequenc": "loop_accountSequenc",
        "ZTCHANNEL-MAIN_loop_updateHead": "loop_updateHead",
        "ZTCHANNEL-MAIN_loop_findNumber": "loop_findNumber",
        "ZTCHANNEL-MAIN_loop_updateHeadHeadPort": "loop_updateHeadHeadPort",
        "ZTCHANNEL-MAIN_loop_updateHeadNickName": "loop_updateHeadNickName",
        "ZTCHANNEL-MAIN_loop_beBound": "loop_beBound",
        "ZTCHANNEL-MAIN_loop_removeNumber": "loop_removeNumber",
        "ZTCHANNEL-MAIN_loop_bindNumber": "loop_bindNumber",
        "ZTCHANNEL-MAIN_loop_sendCode": "loop_sendCode",
        "jszt_trafficAction_getExpireRedList2": "trafficAction_getExpireRedList2",
        "jszt_trafficAction_getBigSalesRedList": "trafficAction_getBigSalesRedList",
        "jszt_trafficAction_getShiXiaoRedList": "trafficAction_getShiXiaoRedList",
        "jszt_trafficAction_getUseRedList": "trafficAction_getUseRedList",
        "jszt_braodband_homeGetInfoByIdCard": "braodband_homeGetInfoByIdCard",
        "ZTCHANNEL-MAIN_loop_uploadHead": "loop_uploadHead",
        "jszt_ipauth_queryAreacodeFromZt": "ipauth_queryAreacodeFromZt",
        "jszt_recharge_getGiveAmount": "recharge_getGiveAmount",
        "ZTCHANNEL-MAIN_businessConfig_listConfigProduct": "businessConfig_listConfigProduct",
        "jszt_rest_getrandomcode": "rest_getrandomcode"
    },
    "vals": {
        "rest_getrandomcode": {
            "code": "rest-00029",
            "url": "http://zt-service.go189.cn/zt-service/rest/getrandomcode"
        },
        "businessConfig_listConfigProduct": {
            "code": "businessConfig-00001",
            "url": "http://zt-config.go189.cn/zt-config/businessConfig/listConfigProduct"
        },
        "ipauth_queryAreacodeFromZt": {
            "code": "ipauth-00002",
            "url": "http://zt-service.go189.cn/zt-service/ipauth/queryAreacodeFromZt"
        },
        "recharge_getGiveAmount": {
            "code": "recharge-00004",
            "url": "http://zt-service.go189.cn/zt-service/recharge/getGiveAmount"
        },
        "loop_bindNumber": {
            "code": "loop-00001",
            "url": "http://zt-service.go189.cn/zt-service/loop/bindNumber"
        },
        "trafficAction_getExpireRedList2": {
            "code": "trafficAction-00004",
            "url": "http://zt-mall.go189.cn/zt-mall/trafficAction/getExpireRedList2"
        },
        "trafficAction_getShiXiaoRedList": {
            "code": "trafficAction-00002",
            "url": "http://zt-mall.go189.cn/zt-mall/trafficAction/getShiXiaoRedList"
        },
        "trafficAction_getBigSalesRedList": {
            "code": "trafficAction-00001",
            "url": "http://zt-mall.go189.cn/zt-mall/trafficAction/getBigSalesRedList"
        },
        "trafficAction_getUseRedList": {
            "code": "trafficAction-00003",
            "url": "http://zt-mall.go189.cn/zt-mall/trafficAction/getUseRedList"
        },
        "loop_updateHeadHeadPort": {
            "code": "loop-00007",
            "url": "http://zt-service.go189.cn/zt-service/loop/updateHeadHeadPort"
        },
        "loop_uploadHead": {
            "code": "loop-00004",
            "url": "http://zt-service.go189.cn/zt-service/loop/uploadHead"
        },
        "loop_removeNumber": {
            "code": "loop-00002",
            "url": "http://zt-service.go189.cn/zt-service/loop/removeNumber"
        },
        "loop_findNumber": {
            "code": "loop-00003",
            "url": "http://zt-service.go189.cn/zt-service/loop/findNumber"
        },
        "loop_updateHeadNickName": {
            "code": "loop-00006",
            "url": "http://zt-service.go189.cn/zt-service/loop/updateHeadNickName"
        },
        "loop_sendCode": {
            "code": "loop-00010",
            "url": "http://zt-service.go189.cn/zt-service/loop/sendCode"
        },
        "loop_updateHead": {
            "code": "loop-00005",
            "url": "http://zt-service.go189.cn/zt-service/loop/updateHead"
        },
        "loop_accountSequenc": {
            "code": "loop-00009",
            "url": "http://zt-service.go189.cn/zt-service/loop/accountSequenc"
        },
        "braodband_homeGetInfoByIdCard": {
            "code": "braodband-00001",
            "url": "http://zt-service.go189.cn/zt-service/braodband/homeGetInfoByIdCard"
        },
        "loop_beBound": {
            "code": "loop-00008",
            "url": "http://zt-service.go189.cn/zt-service/loop/beBound"
        }
    }
};
window.FIX_SIX_ZT_APPEND3 = {
    "keys": {
        "jszt_promotion_getUserMsgBykdId": "promotion_getUserMsgBykdId",
        "jszt_ztauth_queryCzUserInfo": "ztauth_queryCzUserInfo",
        // 触点推荐接口
        "ZTCHANNEL-MAIN_query_queryRecommended": "query_queryRecommended_ztchannel",
        "ZTFLOWORDER_newFlowProduct_getVedioProductList": "newFlowProduct_getVedioProductList",
        "ZTFLOWORDER_flowSearchNotice_getNewFlowSearchTwo": "flowSearchNotice_getNewFlowSearchTwo",
        "ZTFLOWORDER_query_queryRecommended": "query_queryRecommended",
        "jszt_rizuBraodband_checkIsTarget": "rizuBraodband_checkIsTarget",//日租宽带
        "jszt_sameCityAction_checkIsTargetAll": "sameCityAction_checkIsTargetAll",//同城宽带
        "jszt_cz_checkInternetCardRecharge": "cs_checkInternetCardRecharge",//互联网号卡冲送
        "jszt_cz_internetCardRecharge": "cs_internetCardRecharge",//互联网号卡冲送
        "jszt_newOlduserRecharge_isTarget": "cs_isTarget",//老用户冲送 
        "jszt_newOlduserRecharge_NewOlduserRechargeOrderSubmit": "cs_NewOlduserRechargeOrderSubmit",//老用户冲送 
        "jszt_rechargeLotteryAction_queryLotteryChance": "rechargeLotteryAction_queryLotteryChance",//充值抽奖
        "jszt_rechargeLotteryAction_rechargeLottery": "rechargeLotteryAction_rechargeLottery",//充值抽奖
        "jszt_rechargeLotteryAction_getProductList": "rechargeLotteryAction_getProductList",//充值抽奖
         "jszt_rechargeLotteryAction_orderLeakingAssistant": "rechargeLotteryAction_orderLeakingAssistant ",//充值抽奖
        "jszt_hkgj_queryNewPhoneInfo": "hkgj_queryNewPhoneInfo",//回馈购机
        "jszt_hkgj_clickReturn": "hkgj_clickReturn",//回馈购机
        "market_oldUserBuyPhone_checkFeedback": "hkgj_checkFeedback",//回馈购机
        "jszt_tysx_checkReceiveVip": "tysx_checkReceiveVip",//天翼视讯会员
        "jszt_tysx_vipExpireInfo": "tysx_vipExpireInfo",//天翼视讯会员

        // "jszt_freeSpeedUp_checkIsTarget": "freeSpeedUp_checkIsTarget",//免费大提速
        // "jszt_freeSpeedUp_speedUp": "freeSpeedUp_speedUp",//免费大提速
        // "jszt_freeSpeedUp_orderSubmit": "freeSpeedUp_orderSubmit",//免费大提速
        "jszt_twinCard_check": "twinCard_check",//副卡
        "jszt_twinCard_saveRecord": "twinCard_saveRecord",//副卡
        "jszt_twinCard_checkAll": "twinCard_checkAll",//副卡
        "jszt_twinCard_queryInfo": "twinCard_queryInfo",//副卡
        "jszt_twinCard_checkUser": "twinCard_checkUser",//副卡
        "jszt_twinCard_checkAllProduct": "twinCard_checkAllProduct",//副卡
        // "jszt_itvGiftPacksAction_getBroadbandNum": "itvGiftPacksAction_getBroadbandNum",//积分兑换itv
        "jszt_itvGiftPacksAction_itvGoodsOrder": "itvGiftPacksAction_itvGoodsOrder",//积分兑换itv
        "jszt_itvGiftPacksAction_queryItvGoods": "itvGiftPacksAction_queryItvGoods",//积分兑换itv
        "ZTMALLREST_installationITV_getItvBroadbandInfo": "installationITV_getItvBroadbandInfo",//积分兑换itv
        // "jszt_stores_broadbandredeem": "stores_broadbandredeem",//积分兑换宽带提速
        // "jszt_stores_broadBandSpeedUpRedeemSubmit": "stores_broadBandSpeedUpRedeemSubmit",//积分兑换宽带提速
        "jszt_familyNetwork_homePage": "familyNetwork_homePage",//亲情网
        
        "jszt_familyNetwork_createGroup": "familyNetwork_createGroup",//亲情网
        "jszt_familyNetwork_dissolveGroup": "familyNetwork_dissolveGroup",//亲情网
        "jszt_familyNetwork_joinGroup": "familyNetwork_joinGroup",//亲情网
        "jszt_familyNetwork_getCount": "familyNetwork_getCount",//亲情网
        "jszt_familyNetwork_deleteMember": "familyNetwork_deleteMember",//亲情网
        "jszt_familyNetwork_editShortNumber": "familyNetwork_editShortNumber",//亲情网
        "jszt_familyNetwork_bowOut": "familyNetwork_bowOut",//亲情网
        "jszt_familyNetwork_getShortNumberList": "familyNetwork_getShortNumberList",//亲情网
        "jszt_familyNetwork_queryAccnbrs": "familyNetwork_queryAccnbrs",//亲情网
        "jszt_familyNetwork_addOwnNumber": "familyNetwork_addOwnNumber",//亲情网
        "jszt_familyNetwork_inviteBySms": "familyNetwork_inviteBySms",//亲情网
        "jszt_familyNetwork_joinGroupBySms": "familyNetwork_joinGroupBySms",//亲情网
        "jszt_familyNetwork_inviteList": "familyNetwork_inviteList",//亲情网
        "jszt_familyNetwork_faceToFaceInvite": "familyNetwork_faceToFaceInvite",//亲情网
        "jszt_familyNetwork_faceToFaceJoinCheck": "familyNetwork_faceToFaceInviteCheck",//亲情网
        "jszt_familyNetwork_faceToFaceJoin": "familyNetwork_faceToFaceJoin",//亲情网
        "jszt_familyNetwork_weChatInvite": "familyNetwork_weChatInvite",//亲情网
        "jszt_familyNetwork_agreeJoinCheck": "familyNetwork_agreeJoinCheck",//亲情网
        "jszt_familyNetwork_agreeJoin": "familyNetwork_agreeJoin",//亲情网
        "jszt_familyNetwork_checkColledge": "familyNetwork_checkColledge",//亲情网
        "jszt_familyNetwork_createGroupNew": "familyNetwork_createGroupNew",//亲情网
        "jszt_familyNetwork_homePageNew": "familyNetwork_homePageNew",//亲情网
        "jszt_recharge517_isTarget517": "rechargeSend_isTarget",//全国不限量、大王卡充送
        "jszt_recharge517_rechargeOrderSubmit517": "rechargeSend_rechargeOrderSubmit",//全国不限量、大王卡充送
        "jszt_flowSend_luckDraw": "flowSend_luckDraw",//开箱抢流量
        "jszt_flowSend_actionPerson": "flowSend_actionPerson",//开箱抢流量
        "jszt_flowSend_actionAll": "flowSend_actionAll",//开箱抢流量
        "jszt_flowSend_homePageInfo": "flowSend_homePageInfo",//开箱抢流量
        "jszt_flowSend_getFlowInfo": "flowSend_getFlowInfo",//开箱抢流量
        "jszt_flowSend_getRoberInfo": "flowSend_getRoberInfo",//开箱抢流量
        "jszt_flowSend_isHasAward": "flowSend_isHasAward",//开箱抢流量
        "jszt_flowSend_flowDeliveryOrder": "flowSend_flowDeliveryOrder",//开箱抢流量
        "jszt_flowSend_getReachStandardFlow": "flowSend_getReachStandardFlow",//开箱抢流量
        "jszt_flowSend_sendDelivery": "flowSend_sendDelivery",//开箱抢流量
        "jszt_flowSend_flowAndTimesLeft": "flowSend_flowAndTimesLeft",//开箱抢流量
        "jszt_flowSend_havaFlowNotGet": "flowSend_havaFlowNotGet",//开箱抢流量
        "jszt_flowSend_sendDeliveryNew": "flowSend_sendDeliveryNew",//开箱抢流量
        "jszt_newuser_receivePackageNew": "newuser_receivePackageNew",//新人礼
        "jszt_promotion_isOldUser2": "newuser_isOldUser2",//新人礼
         "jszt_newuser_checkIsShowPackageNew": "newuser_checkIsShowPackageNew",//新人礼
                "jszt_hiCardAction_visitorAndOrderInfo": "hiCardAction_visitorAndOrderInfo",//升级
        // "jszt_jiFenActon_getSignedDays": "signLotteryAction_getSignedDays",//签到送积分
        "jszt_jiFenActon_getProductList": "signLotteryAction_getProductList",//签到送积分
        "jszt_jiFenActon_isInfinityHiCardUser": "signLotteryAction_isInfinityHiCardUser",//签到送积分
        "jszt_jiFenActon_scoreIncreaseDetail": "signLotteryAction_scoreIncreaseDetail",//签到送积分
        // "jszt_jiFenActon_getProductListHalfYear": "signLotteryAction_getProductListHalfYear",//签到送积分
        "jszt_jiFenActon_sendPointForLottery": "signLotteryAction_sendPointForLottery",//签到送积分
        // "jszt_jiFenActon_signLotteryNew": "signLotteryAction_signLotteryNew",//签到送积分
        // "jszt_chargeWalletAction_myRewardList": "chargeWalletAction_myRewardList",//话费钱包
        // "jszt_chargeWalletAction_newTypeDrawCash": "chargeWalletAction_newTypeDrawCash",//话费钱包
        // "jszt_chargeWalletAction_isDrawCash": "chargeWalletAction_isDrawCash",//话费钱包
        // "jszt_chargeWalletAction_checkCard": "chargeWalletAction_checkCard",//话费钱包
        "jszt_lotteryAction_refereeInfo": "counselorRecommend_refereeInfo",//人人推
        "jszt_lotteryAction_refereeGains": "counselorRecommend_refereeGains",//人人推
        "jszt_renRenTuiJianAction_sweepCodeForGift": "counselorRecommend_sweepCodeForGift",//人人推
        "jszt_renRenTuiJianAction_isReferee": "counselorRecommend_isReferee",//人人推
        "jszt_newuser_getActivityRules": "rules_getActivityRules",//活动规则
        "jszt_pictureCode_getRandomNumberCode": "login_getRandomNumberCode",//图形验证码
        "jszt_ztserverauth_noLoginOrderPackage2": "otherlogin_noLoginOrderPackage2",//集团免登陆
        "ZTCHANNEL-MAIN_query_participateNumber": "query_participateNumber",
        "ZTMALLREST_broadBandBuiness_broadBandSpeedControl": "broadBandBuiness_broadBandSpeedControl",
        "ZTMALLREST_broadBandBuiness_submitBroadBandChargeSpeedOrder": "broadBandBuiness_submitBroadBandChargeSpeedOrder",
        "zt-login_otherlogin_noPswdlogin": "otherlogin_noPswdlogin",
        "zt-login_login_innerAccount": "login_innerAccount",
        "jszt_ztserverauth_ztWeiXinServiceNoLogin": "ztserverauth_ztWeiXinServiceNoLogin",
        "ZTMALLREST_broadBandBuiness_queryNatAccountByiTV": "broadBandBuiness_queryNatAccountByiTV",
        "ZTMALLREST_broadBandReNew_queryBroadBandInfoByThirdOfAccNbr": "broadBandReNew_queryBroadBandInfoByThirdOfAccNbr",
        "ZTMALLREST_broadBandReNew_queryBroadBandInfoByIdCard": "broadBandReNew_queryBroadBandInfoByIdCard",
        "ZTMALLREST_broadBandReNew_queryMentionInfo": "broadBandReNew_queryMentionInfo",
        "ZTMALLREST_broadBandReNew_saveIntention": "broadBandReNew_saveIntention",
        "ZTMALLREST_broadBandReNew_luckQualifications": "broadBandReNew_luckQualifications",
        "ZTMALLREST_broadBandReNew_luckDraw": "broadBandReNew_luckDraw",
        "ZTMALLREST_broadBandReNew_queryIsDrawed": "broadBandReNew_queryIsDrawed",
        "ZTMALLREST_broadbandManager_queryBroadbandByLoginNbr": "broadbandManager_queryBroadbandByLoginNbr",
        "ZTMALLREST_broadBandBuiness_selectUserBroadAccNbrNew": "broadBandBuiness_selectUserBroadAccNbrNew",
        "ZTMALLREST_installationITV_queryBroadbandInformationByIdCard": "installationITV_queryBroadbandInformationByIdCard",
        "ZTMALLREST_installationITV_queryBroadbandInformationByAccNbr": "installationITV_queryBroadbandInformationByAccNbr",
        "ZTMALLREST_installationITV_querySaleGoodInfoByAccNbr": "installationITV_querySaleGoodInfoByAccNbr",
        "ZTMALLREST_installationITV_makeAppointment": "installationITV_makeAppointment",
        "jszt_rest_login2UserInfo": "rest_login2UserInfo",
        "ZTFLOWORDER_jifenExchange_exchange": "integrationExchange_exchangePhoneCharge",//积分兑换
        "zt-market_order_saveITVOrder": "order_saveITVOrder",
    },
    "vals": {
        "promotion_getUserMsgBykdId": {
            "code": "wxxcx-00006",
            "url": "http://zt-activity.go189.cn/zt-activity/promotion/getUserMsgBykdId"
        },
        "ztauth_queryCzUserInfo": {
            // "code": "wxxcx-00005",
            // "url": "http://zt-acativity.go189.cn/zt-acativity/ztauth/queryCzUserInfo"
            "code": "jszt-00076",
            "url": "http://zt-business.go189.cn/zt-business/ztauth/queryCzUserInfo"
        },
        "query_queryRecommended_ztchannel": {
            "code": "query-00001",
            "url": "http://zt-service.go189.cn/zt-service/query/queryRecommended"
        },
        "flowSearchNotice_getNewFlowSearchTwo": {
            "code": "flow-00020",
            "url": "http://zt-business.go189.cn/zt-business/flowSearchNotice/getNewFlowSearchTwo"
        },
        "newFlowProduct_getVedioProductList": {
            "code": "flow-00021",
            "url": "http://zt-business.go189.cn/zt-business/newFlowProduct/getVedioProductList"
        },
     
        "query_queryRecommended": {
            "code": "query-00001",
            "url": "http://zt-service.go189.cn/zt-service/query/queryRecommended"
        },
        "rizuBraodband_checkIsTarget": {
            "code": "activitys-00010",
            "url": "http://zt-activity.go189.cn/zt-activity/rizuBraodband/checkIsTarget"
        },
        "sameCityAction_checkIsTargetAll": {
            "code": "activitys-00009",
            "url": "http://zt-activity.go189.cn/zt-activity/sameCityAction/checkIsTargetAll"
        },
        "cs_checkInternetCardRecharge": {
            "code": "recharge-00001",
            "url": "http://zt-activity.go189.cn/zt-activity/cs/checkInternetCardRecharge"
        },
        "cs_internetCardRecharge": {
            "code": "recharge-00002",
            "url": "http://zt-activity.go189.cn/zt-activity/cs/internetCardRecharge"
        },
        "cs_isTarget": {
            "code": "recharge-00003",
            "url": "http://zt-activity.go189.cn/zt-activity/cs/isTarget"
        },
        "cs_NewOlduserRechargeOrderSubmit": {
            "code": "recharge-00004",
            "url": "http://zt-activity.go189.cn/zt-activity/cs/NewOlduserRechargeOrderSubmit"
        },
        "rechargeLotteryAction_queryLotteryChance": {
            "code": "recharge-00005",
            "url": "http://zt-activity.go189.cn/zt-activity/rechargeLotteryAction/queryLotteryChance"
        },
        "rechargeLotteryAction_rechargeLottery": {
            "code": "recharge-00006",
            "url": "http://zt-activity.go189.cn/zt-activity/rechargeLotteryAction/rechargeLottery"
        },
        "rechargeLotteryAction_getProductList": {
            "code": "recharge-00007",
            "url": "http://zt-activity.go189.cn/zt-activity/rechargeLotteryAction/getProductList"
        },
        "rechargeLotteryAction_orderLeakingAssistant": {
            "code": "recharge-00008",
            "url": "http://zt-activity.go189.cn/zt-activity/rechargeLotteryAction/orderLeakingAssistant"
        },
        "hkgj_queryNewPhoneInfo": {
            "code": "olduserbuyphone-00001",
            "url": "http://zt-activity.go189.cn/zt-activity/hkgj/queryNewPhoneInfo"
        },
        "hkgj_clickReturn": {
            "code": "olduserbuyphone-00002",
            "url": "http://zt-activity.go189.cn/zt-activity/hkgj/clickReturn"
        },
        "hkgj_checkFeedback": {
            "code": "olduserbuyphone-00003",
            "url": "http://zt-activity.go189.cn/zt-activity/hkgj/checkFeedback"
        },
        "tysx_checkReceiveVip": {
            "code": "video-00001",
            "url": "http://zt-activity.go189.cn/zt-activity/tysx/checkReceiveVip"
        },
        "tysx_vipExpireInfo": {
            "code": "video-00002",
            "url": "http://zt-activity.go189.cn/zt-activity/tysx/vipExpireInfo"
        },
        "cloudStorePreheatAction_receiveTicketNew": {
            "code": "wisdomfamily-00001",
            "url": "http://zt-activity.go189.cn/zt-activity/cloudStorePreheatAction/receiveTicketNew"
        },
        "tysx_vipExpireInfo": {
            "code": "wisdomfamily-00002",
            "url": "http://zt-activity.go189.cn/zt-activity/cloudStorePreheatAction/getTicketInfo"
        },
        "freeSpeedUp_checkIsTarget": {
            "code": "activitys-00006",
            "url": "http://zt-activity.go189.cn/zt-activity/freeSpeedUp/checkIsTarget"
        },
        "freeSpeedUp_speedUp": {
            "code": "activitys-00007",
            "url": "http://zt-activity.go189.cn/zt-activity/freeSpeedUp/speedUp"
        },
        "freeSpeedUp_orderSubmit": {
            "code": "activitys-00008",
            "url": "http://zt-activity.go189.cn/zt-activity/freeSpeedUp/orderSubmit"
        },
        "twinCard_check": {
            "code": "twincard-00001",
            "url": "http://zt-activity.go189.cn/zt-activity/twinCard/check"
        } ,
        "twinCard_saveRecord": {
            "code": "twincard-00002",
            "url": "http://zt-activity.go189.cn/zt-activity/twinCard/saveRecord"
        } ,
        "twinCard_checkAll": {
            "code": "twincard-00003",
            "url": "http://zt-activity.go189.cn/zt-activity/twinCard/checkAll"
        } ,
        "twinCard_checkUser": {
            "code": "twincard-00005",
            "url": "http://zt-activity.go189.cn/zt-activity/twinCard/checkUser"
        } ,
        "twinCard_queryInfo": {
            "code": "twincard-00004",
            "url": "http://zt-activity.go189.cn/zt-activity/twinCard/queryInfo"
        } ,
        "twinCard_checkAllProduct": {
            "code": "twincard-00006",
            "url": "http://zt-activity.go189.cn/zt-activity/twinCard/checkAllProduct"
        } ,
        "itvGiftPacksAction_getBroadbandNum": {
            "code": "itvGiftPacks-00001",
            "url": "http://zt-activity.go189.cn/zt-activity/itvGiftPacksAction/getBroadbandNum"
        } ,
        "itvGiftPacksAction_itvGoodsOrder": {
            "code": "itvGiftPacks-00002",
            "url": "http://zt-activity.go189.cn/zt-activity/itvGiftPacksAction/itvGoodsOrder"
        } ,
        "itvGiftPacksAction_queryItvGoods": {
            "code": "itvGiftPacks-00003",
            "url": "http://zt-activity.go189.cn/zt-activity/itvGiftPacksAction/queryItvGoods"
        } ,
        "installationITV_getItvBroadbandInfo": {
            "code": "installationITV-00001",
            "url": "http://zt-activity.go189.cn/zt-activity/installationITV/getItvBroadbandInfo"
        } ,
        "stores_broadbandredeem": {
            "code": "broadbandRedeem-00001",
            "url": "http://zt-activity.go189.cn/zt-activity/stores/broadbandredeem"
        } ,
        "stores_broadBandSpeedUpRedeemSubmit": {
            "code": "broadbandRedeem-00002",
            "url": "http://zt-activity.go189.cn/zt-activity/stores/broadBandSpeedUpRedeemSubmit"
        },
        "familyNetwork_homePage": {
            "code": "familyNetwork-00001",
            "url": "http://zt-activity.go189.cn/zt-activity/familyNetwork/homePage"
        },
        "familyNetwork_faceToFaceJoinCheck": {
            "code": "familyNetwork-00016",
            "url": "http://zt-activity.go189.cn/zt-activity/familyNetwork/faceToFaceInviteCheck"
        },
        "familyNetwork_createGroup": {
            "code": "familyNetwork-00002",
            "url": "http://zt-activity.go189.cn/zt-activity/familyNetwork/createGroup"
        },
        "familyNetwork_dissolveGroup": {
            "code": "familyNetwork-00003",
            "url": "http://zt-activity.go189.cn/zt-activity/familyNetwork/dissolveGroup"
        },
        "familyNetwork_joinGroup": {
            "code": "familyNetwork-00004",
            "url": "http://zt-activity.go189.cn/zt-activity/familyNetwork/joinGroup"
        },
        "familyNetwork_getCount": {
            "code": "familyNetwork-00005",
            "url": "http://zt-activity.go189.cn/zt-activity/familyNetwork/getCount"
        },
        "familyNetwork_deleteMember": {
            "code": "familyNetwork-00006",
            "url": "http://zt-activity.go189.cn/zt-activity/familyNetwork/deleteMember"
        },
        "familyNetwork_editShortNumber": {
            "code": "familyNetwork-00007",
            "url": "http://zt-activity.go189.cn/zt-activity/familyNetwork/editShortNumber"
        },
        "familyNetwork_bowOut": {
            "code": "familyNetwork-00008",
            "url": "http://zt-activity.go189.cn/zt-activity/familyNetwork/bowOut"
        },
        "familyNetwork_getShortNumberList": {
            "code": "familyNetwork-00009",
            "url": "http://zt-activity.go189.cn/zt-activity/familyNetwork/getShortNumberList"
        },
        "familyNetwork_queryAccnbrs": {
            "code": "familyNetwork-00010",
            "url": "http://zt-activity.go189.cn/zt-activity/familyNetwork/queryAccnbrs"
        },
        "familyNetwork_addOwnNumber": {
            "code": "familyNetwork-00011",
            "url": "http://zt-activity.go189.cn/zt-activity/familyNetwork/addOwnNumber"
        },
        "familyNetwork_inviteBySms": {
            "code": "familyNetwork-00012",
            "url": "http://zt-activity.go189.cn/zt-activity/familyNetwork/inviteBySms"
        },
        "familyNetwork_joinGroupBySms": {
            "code": "familyNetwork-00013",
            "url": "http://zt-activity.go189.cn/zt-activity/familyNetwork/joinGroupBySms"
        },
        "familyNetwork_inviteList": {
            "code": "familyNetwork-00014",
            "url": "http://zt-activity.go189.cn/zt-activity/familyNetwork/inviteList"
        },
        "familyNetwork_faceToFaceInvite": {
            "code": "familyNetwork-00015",
            "url": "http://zt-activity.go189.cn/zt-activity/familyNetwork/faceToFaceInvite"
        },
        "familyNetwork_faceToFaceInviteCheck": {
            "code": "familyNetwork-00016",
            "url": "http://zt-activity.go189.cn/zt-activity/familyNetwork/faceToFaceInviteCheck"
        },
        "familyNetwork_faceToFaceJoin": {
            "code": "familyNetwork-00017",
            "url": "http://zt-activity.go189.cn/zt-activity/familyNetwork/faceToFaceJoin"
        },
        "familyNetwork_weChatInvite": {
            "code": "familyNetwork-00018",
            "url": "http://zt-activity.go189.cn/zt-activity/familyNetwork/weChatInvite"
        },
        "familyNetwork_agreeJoinCheck": {
            "code": "familyNetwork-00019",
            "url": "http://zt-activity.go189.cn/zt-activity/familyNetwork/agreeJoinCheck"
        },
        "familyNetwork_agreeJoin": {
            "code": "familyNetwork-00020",
            "url": "http://zt-activity.go189.cn/zt-activity/familyNetwork/agreeJoin"
        },
        "familyNetwork_checkColledge": {
            "code": "familyNetwork-00021",
            "url": "http://zt-activity.go189.cn/zt-activity/familyNetwork/checkColledge"
        },
        "familyNetwork_createGroupNew": {
            "code": "familyNetwork-00022",
            "url": "http://zt-activity.go189.cn/zt-activity/familyNetwork/createGroupNew"
        },
        "familyNetwork_homePageNew": {
            "code": "familyNetwork-00023",
            "url": "http://zt-activity.go189.cn/zt-activity/familyNetwork/homePageNew"
        },
        "rechargeSend_isTarget": {
            "code": "recharge-00009",
            "url": "http://zt-activity.go189.cn/zt-activity/rechargeSend/isTarget"
        },
        "rechargeSend_rechargeOrderSubmit": {
            "code": "recharge-00010",
            "url": "http://zt-activity.go189.cn/zt-activity/rechargeSend/rechargeOrderSubmit"
        },
        "flowSend_luckDraw": {
            "code": "flowSend-00001",
            "url": "http://zt-activity.go189.cn/zt-activity/flowSend/luckDraw"
        },
        "flowSend_actionPerson": {
            "code": "flowSend-00002",
            "url": "http://zt-activity.go189.cn/zt-activity/flowSend/actionPerson"
        },
        "flowSend_actionAll": {
            "code": "flowSend-00003",
            "url": "http://zt-activity.go189.cn/zt-activity/flowSend/actionAll"
        },
        "flowSend_homePageInfo": {
            "code": "flowSend-00004",
            "url": "http://zt-activity.go189.cn/zt-activity/flowSend/homePageInfo"
        },
        "flowSend_getFlowInfo": {
            "code": "flowSend-00005",
            "url": "http://zt-activity.go189.cn/zt-activity/flowSend/getFlowInfo"
        },
        "flowSend_getRoberInfo": {
            "code": "flowSend-00006",
            "url": "http://zt-activity.go189.cn/zt-activity/flowSend/getRoberInfo"
        },
        "flowSend_isHasAward": {
            "code": "flowSend-00007",
            "url": "http://zt-activity.go189.cn/zt-activity/flowSend/isHasAward"
        },
        "flowSend_flowDeliveryOrder": {
            "code": "flowSend-00008",
            "url": "http://zt-activity.go189.cn/zt-activity/flowSend/flowDeliveryOrder"
        },
        "flowSend_getReachStandardFlow": {
            "code": "flowSend-00009",
            "url": "http://zt-activity.go189.cn/zt-activity/flowSend/getReachStandardFlow"
        },
        "flowSend_sendDelivery": {
            "code": "flowSend-00010",
            "url": "http://zt-activity.go189.cn/zt-activity/flowSend/sendDelivery"
        },
        "flowSend_flowAndTimesLeft": {
            "code": "flowSend-00011",
            "url": "http://zt-activity.go189.cn/zt-activity/flowSend/flowAndTimesLeft"
        },
        "flowSend_havaFlowNotGet": {
            "code": "flowSend-00012",
            "url": "http://zt-activity.go189.cn/zt-activity/flowSend/havaFlowNotGet"
        },
        "flowSend_sendDeliveryNew": {
            "code": "flowSend-00013",
            "url": "http://zt-activity.go189.cn/zt-activity/flowSend/sendDeliveryNew"
        },
        "newuser_checkIsShowPackageNew": {
            "code": "newUser-00001",
            "url": "http://zt-activity.go189.cn/zt-activity/newuser/checkIsShowPackageNew"
        },
        "newuser_receivePackageNew": {
            "code": "newUser-00002",
            "url": "http://zt-activity.go189.cn/zt-activity/newuser/receivePackageNew"
        },
        "newuser_isOldUser2": {
            "code": "newUser-00003",
            "url": "http://zt-activity.go189.cn/zt-activity/newuser/isOldUser2"
        },
        "signLotteryAction_getSignedDays": {
            "code": "signLottery-00001",
            "url": "http://zt-activity.go189.cn/zt-activity/signLotteryAction/getSignedDays"
        },
        "signLotteryAction_getProductList": {
            "code": "signLottery-00002",
            "url": "http://zt-activity.go189.cn/zt-activity/signLotteryAction/getProductList"
        },
        "signLotteryAction_isInfinityHiCardUser": {
            "code": "signLottery-00003",
            "url": "http://zt-activity.go189.cn/zt-activity/signLotteryAction/isInfinityHiCardUser"
        },
        "signLotteryAction_scoreIncreaseDetail": {
            "code": "signLottery-00004",
            "url": "http://zt-activity.go189.cn/zt-activity/signLotteryAction/scoreIncreaseDetail"
        },
        "signLotteryAction_getProductListHalfYear": {
            "code": "signLottery-00005",
            "url": "http://zt-activity.go189.cn/zt-activity/signLotteryAction/getProductListHalfYear"
        },
        "signLotteryAction_sendPointForLottery": {
            "code": "signLottery-00006",
            "url": "http://zt-activity.go189.cn/zt-activity/signLotteryAction/sendPointForLottery"
        },
        "signLotteryAction_signLotteryNew": {
            "code": "signLottery-00007",
            "url": "http://zt-activity.go189.cn/zt-activity/signLotteryAction/signLotteryNew"
        },
        "chargeWalletAction_myRewardList": {
            "code": "chargeWallet-00001",
            "url": "http://zt-activity.go189.cn/zt-activity/chargeWalletAction/myRewardList"
        },
        "chargeWalletAction_newTypeDrawCash": {
            "code": "chargeWallet-00002",
            "url": "http://zt-activity.go189.cn/zt-activity/chargeWalletAction/newTypeDrawCash"
        },
        "chargeWalletAction_isDrawCash": {
            "code": "chargeWallet-00003",
            "url": "http://zt-activity.go189.cn/zt-activity/chargeWalletAction/isDrawCash"
        },
        "chargeWalletAction_checkCard": {
            "code": "chargeWallet-00004",
            "url": "http://zt-activity.go189.cn/zt-activity/chargeWalletAction/checkCard"
        },
        "counselorRecommend_refereeInfo": {
            "code": "counselorRecommend-00001",
            "url": "http://zt-activity.go189.cn/zt-activity/counselorRecommend/refereeInfo"
        },
        "counselorRecommend_refereeGains": {
            "code": "counselorRecommend-00002",
            "url": "http://zt-activity.go189.cn/zt-activity/counselorRecommend/refereeGains"
        },
        "counselorRecommend_sweepCodeForGift": {
            "code": "counselorRecommend-00003",
            "url": "http://zt-activity.go189.cn/zt-activity/refereeGains/sweepCodeForGift"
        },
        "counselorRecommend_isReferee": {
            "code": "counselorRecommend-00004",
            "url": "http://zt-activity.go189.cn/zt-activity/refereeGains/isReferee"
        },
        "hiCardAction_visitorAndOrderInfo": {
            "code": "pvuv-0001",
            "url": "http://zt-activity.go189.cn/zt-activity/hiCardAction/visitorAndOrderInfo"
        },
        "rules_getActivityRules": {
            "code": "rule-0001",
            "url": "http://zt-activity.go189.cn/zt-activity/rules/getActivityRules"
        },
        "login_getRandomNumberCode": {
            "code": "login-00008",
            "url": "http://zt-login.go189.cn/zt-login/login/getRandomNumberCode"
        },
        "otherlogin_noLoginOrderPackage2": {
            "code": "otherlogin-00001",
            "url": "http://zt-login.go189.cn/zt-login/otherlogin/noLoginOrderPackage2"
        },
        "query_participateNumber": {
            "code": "query-00003",
            "url": "http://zt-service.go189.cn/zt-service/welcome"
        },
        "broadBandBuiness_broadBandSpeedControl": {
            "code": "mall-00052",
            "url": "http://zt-business.go189.cn/zt-business/welcome"
        },
        "broadBandBuiness_submitBroadBandChargeSpeedOrder": {
            "code": "jszt-00066",
            "url": "http://zt-business.go189.cn/zt-business/welcome"
        },
        "otherlogin_noPswdlogin": {
            "code": "otherlogin-00001",
            "url": "http://zt-login.go189.cn/zt-login/welcome"
        },
        "login_innerAccount": {
            "code": "login-00001",
            "url": "http://zt-login.go189.cn/zt-login/welcome"
        },
        "ztserverauth_ztWeiXinServiceNoLogin": {
            "code": "otherlogin-00010",
            "url": "http://zt-login.go189.cn/zt-login/welcome"
        },
        "broadBandBuiness_queryNatAccountByiTV": {
            "code": "mall-00051",
            "url": "http://zt-business.go189.cn/zt-business/welcome"
        },
        "broadBandReNew_queryBroadBandInfoByThirdOfAccNbr": {
            "code": "broadBandReNew-00001",
            "url": "http://zt-mall.go189.cn/zt-mall/welcome"
        },
        "broadBandReNew_queryBroadBandInfoByIdCard": {
            "code": "broadBandReNew-00002",
            "url": "http://zt-mall.go189.cn/zt-mall/welcome"
        },
        "broadBandReNew_queryMentionInfo": {
            "code": "broadBandReNew-00003",
            "url": "http://zt-mall.go189.cn/zt-mall/welcome"
        },
        "broadBandReNew_saveIntention": {
            "code": "broadBandReNew-00004",
            "url": "http://zt-mall.go189.cn/zt-mall/welcome"
        },
        "broadBandReNew_luckQualifications": {
            "code": "broadBandReNew-00005",
            "url": "http://zt-mall.go189.cn/zt-mall/welcome"
        },
        "broadBandReNew_luckDraw": {
            "code": "broadBandReNew-00006",
            "url": "http://zt-mall.go189.cn/zt-mall/welcome"
        },
        "broadBandReNew_queryIsDrawed": {
            "code": "broadBandReNew-00007",
            "url": "http://zt-mall.go189.cn/zt-mall/welcome"
        },
        "broadbandManager_queryBroadbandByLoginNbr": {
            "code": "mall-00034",
            "url": "http://zt-business.go189.cn/zt-business/welcome"
        },
        "broadBandBuiness_selectUserBroadAccNbrNew": {
            "code": "mall-00033",
            "url": "http://zt-business.go189.cn/zt-business/welcome"
        },
        "installationITV_queryBroadbandInformationByIdCard": {
            "code": "mall-00008",
            "url": "http://zt-business.go189.cn/zt-business/welcome"
        },
        "installationITV_queryBroadbandInformationByAccNbr": {
            "code": "mall-00044",
            "url": "http://zt-business.go189.cn/zt-business/welcome"
        },
        "installationITV_querySaleGoodInfoByAccNbr": {
            "code": "mall-00052",
            "url": "http://zt-business.go189.cn/zt-business/welcome"
        },
        "installationITV_makeAppointment": {
            "code": "mall-00053",
            "url": "http://zt-business.go189.cn/zt-business/welcome"
        },
        "rest_login2UserInfo": {
            "code": "rest-00026",
            "url": "http://zt-service.go189.cn/zt-service/welcome"
        },
        "integrationExchange_exchangePhoneCharge": {
            "code": "integrationExchange-00001",
            "url": "http://zt-business.go189.cn/zt-business/integrationExchange/exchangePhoneCharge"
        },
        "order_saveITVOrder": {
            "code": "order-00004",
            "url": "http://zt-mall.go189.cn/zt-mall/welcome"
        }
    }
};
window.FIX_SIX_ZT_APPEND4 = {
    "keys": {
        "ZTMALLREST_broadBandBuiness_searchPackageAndUserMessageByPhone":"broadBandBuiness_searchPackageAndUserMessageByPhone",
        //"jszt_jiFenActon_getSignedDays": "jiFenActon_getSignedDays",
        //"jszt_jiFenActon_getProductListHalfYear": "jiFenActon_getProductListHalfYear",
        //"jszt_jiFenActon_isHiInfinityCardUser": "jiFenActon_isHiInfinityCardUser",
        //"jszt_jiFenActon_signLottery": "jiFenActon_signLottery",
        "jszt_rest_scoreQueryDetail": "rest_scoreQueryDetail",
        //"jszt_jiFenActon_scoreIncreaseDetail": "jiFenActon_scoreIncreaseDetail",
        //"jszt_jiFenActon_getProductList": "jiFenActon_getProductList",
        "jszt_familyHiUpgrade_getVisitors": "familyHiUpgrade_getVisitors",
        "jszt_ztauth_verifyIdentity":"ztauth_verifyIdentity"

    },
    "vals": {
        "ztauth_verifyIdentity":{
            "code":"jszt-00064",
            "url":"http://zt-business.go189.cn//zt-business/ztauth/verifyIdentity"
        },
        "familyHiUpgrade_getVisitors": {
            "code": "familyHiUpgrade-00001",
            "url": "http://zt-service.go189.cn//zt-service/familyHiUpgrade/getVisitors"
        },
        "broadBandBuiness_searchPackageAndUserMessageByPhone": {
            "code": "mall-00023",
            "url": "http://zt-business.go189.cn/zt-business/broadBandBuiness/searchPackageAndUserMessageByPhone"
        },
        "jiFenActon_getSignedDays": {
            "code": "jiFenActon-00002",
            "url": "http://zt-score.go189.cn/zt-score/jiFenActon/getSignedDays"
        },
        "jiFenActon_isHiInfinityCardUser": {
            "code": "jiFenActon-00004",
            "url": "http://zt-score.go189.cn/zt-score/jiFenActon/isHiInfinityCardUser"
        },
        "jiFenActon_signLottery": {
            "code": "jiFenActon-00001",
            "url": "http://zt-score.go189.cn/zt-score/jiFenActon/signLottery"
        },
        "jiFenActon_getProductList": {
            "code": "jiFenActon-00003",
            "url": "http://zt-score.go189.cn/zt-score/jiFenActon/getProductList"
        },
        "rest_scoreQueryDetail": {
            "code": "tempScore-00003",
            "url": "http://zt-score.go189.cn/zt-score/rest/scoreQueryDetail"
        },
        "jiFenActon_getProductListHalfYear": {
            "code": "jiFenActon-00006",
            "url": "http://zt-score.go189.cn/zt-score/jiFenActon/getProductListHalfYear"
        },
        "jiFenActon_scoreIncreaseDetail": {
            "code": "jiFenActon-00005",
            "url": "http://zt-score.go189.cn/zt-score/jiFenActon/scoreIncreaseDetail"
        }
    }
};
window.FIX_SIX_CONDITIONS = ['FIX_SIX_ZT_SERVICE', 'FIX_SIX_ZT_SCORE', 'FIX_SIX_ZT_PAY',
    'FIX_SIX_ZT_MALL', 'FIX_SIX_ZT_LOGIN', 'FIX_SIX_ZT_CONFIG', 'FIX_SIX_ZT_BUSINESS', 'FIX_SIX_ZT_APP'
    , 'FIX_SIX_ZT_APPEND', 'FIX_SIX_ZT_APPEND1', 'FIX_SIX_ZT_APPEND2', 'FIX_SIX_ZT_APPEND3', 'FIX_SIX_ZT_APPEND4'];
window.FIX_SIX_CONDITION = {
    'ZtFlowOrder': 'ZTFLOWORDER',
    'ZtMallRest': 'ZTMALLREST',
    'ztChannel-main': 'ZTCHANNEL-MAIN',
    'jszt': 'jszt',
    'LoginAuth': 'jszt',
    'zt-market': 'market',
    'zt-pay': 'ZT-PAY',
    'ztjklj': 'jszt',
    'zt-login':'zt-login'
};
window.FIX_SIX_OPT = {};
window.FIX_SIX_OPT.fixUrl = function (option) {
    try {
        var url = option.url;
        var para = option.data.para || '';
        var urlArray = url.split('/');
        if (urlArray[3]) {
            var cKey = urlArray[3];
            var coKey = FIX_SIX_CONDITION[cKey];
            var fIndex = urlArray.length-2;
            var sIndex = urlArray.length-1;
            if (coKey) {
                var keys = null;
                for (var i = 0; i < FIX_SIX_CONDITIONS.length; i++) {
                    var key = window[FIX_SIX_CONDITIONS[i]].keys[coKey + '_' + urlArray[fIndex] + '_' + urlArray[sIndex]];
                    if (key) {
                        keys = window[FIX_SIX_CONDITIONS[i]].vals[key];
                        break;
                    }
                }
                if (keys) {
                    option.url = keys.url;
                    
//                    if (option.url.indexOf("zt-login.go189.cn") > 0){
//                        option.url = option.url.replace("zt-login.go189.cn","221.228.47.27:12000");
//                    }
//                    if (option.url.indexOf("zt-service.go189.cn") > 0){
//                        option.url = option.url.replace("zt-service.go189.cn","221.228.47.27:12000");
//                    }
//                    if (option.url.indexOf("zt-app.go189.cn") > 0){
//                        option.url = option.url.replace("zt-app.go189.cn","221.228.47.27:12000");
//                    }
//                    if (option.url.indexOf("zt-mall.go189.cn") > 0){
//                        option.url = option.url.replace("zt-mall.go189.cn","221.228.47.27:12000");
//                    }
//                    if (option.url.indexOf("zt-business.go189.cn") > 0){
//                        option.url = option.url.replace("zt-business.go189.cn","221.228.47.27:12000");
//                    }
//                    if (option.url.indexOf("zt-pay.go189.cn") > 0){
//                        option.url = option.url.replace("zt-pay.go189.cn","221.228.47.27:12000");
//                    }
//                    if (option.url.indexOf("zt-score.go189.cn") > 0){
//                        option.url = option.url.replace("zt-score.go189.cn","221.228.47.27:12000");
//                    }
                    option.data.para = 'PathCode=' + keys.code + ';' + para;
                    option.PathCode = keys.code;
                    option.newDes = 1;
                    option.charset = 0;
//                    console.error('FIX_SIX_OPT:' + url + '__' + keys.url + '__' + keys.code);
                }
            }
        }
		option.url = handleDomainContent(option.url);
    } catch (e) {
        console.error('FIX_SIX_OPT:' + JSON.stringify(e));
    }
};