/**
 * 微信支付插件定义
 */
cordova.define("weixin.WeixinPay", function(require, exports, module) {
	var exec = require('cordova/exec');
	
	/**
	 * 微信支付对象
	 */
	var WeixinPay = function(){
		/**
		 * 回调方法map
		 */
		this.callback = {};
		this.authcallback = {};
	}
	
	/**
	 * 微信支付方法定义
	 */
	WeixinPay.prototype = {
			/**
			 * 是否为空
			 */
			isNull:function(obj){
				return obj == null || obj == '' || obj.toString() == '';
			},
			/**
			 * 执行回调方法
			 */
			excuteCallback:function(errCode,errMsg){
				if(errCode == 0 || errCode == '0'){
					this.callback.success && this.callback.success(errCode,errMsg);
				}else{
					this.callback.error && this.callback.error(errCode,errMsg);
				}
			},

            /**
			 * 执行auth回调方法
			 */
			excuteAuthCallback:function(errCode){
				
				if(errCode == 0 || errCode == '0'){
					this.authcallback.success && this.authcallback.success(errCode);
				}else{
					this.authcallback.error && this.authcallback.error(errCode);
				}
			},
			/**
			 * 必填参数校验
			 */
			validate:function(option){
				if(this.isNull(option)){
					return false;
				}
				if(this.isNull(option.appid)){
					return false;
				}
				if(this.isNull(option.partnerid)){
					return false;
				}
				if(this.isNull(option.prepayid)){
					return false;
				}
				if(this.isNull(option.package)){
					return false;
				}
				if(this.isNull(option.noncestr)){
					return false;
				}
				if(this.isNull(option.timestamp)){
					return false;
				}
				if(this.isNull(option.sign)){
					return false;
				}
				this.callback = {
					success:option.success,
					error:option.error
				}
				return true;
			},



			/**
			 * 将json参数转化成数组形式
			 */
			toArgs:function(option){
				var args = [
					option
				];
				return args;
			},
			/**
			 * 分享方法入口调用
			 * @param {Object} option 分享参数
			 * @param {String} option.appid 应用id
			 * @param {String} option.partnerid 商家id
			 * @param {String} option.prepayid 预支付id
			 * @param {String} option.package 商品
			 * @param {String} option.noncestr 混淆key
			 * @param {String} option.timestamp 时间戳
			 * @param {String} option.sign 签名
			 * @param {Function} option.success 支付的成功回调
			 * @param {Function} option.error 支付的失败回调
			 */
			pay:function(option){
				if(!this.validate(option)){
					return;
				}
				exec(option.success,option.error,"WeixinPay","pay",this.toArgs(option));
			},
			openWebviewReq:function(success,error,url){
				
				exec(success,error,"WeixinPay","openWebviewReq",[url]);
			},
			openInvoiceAuthReq:function(success,error,url){

				this.authcallback = {
					success:success,
					error:error
				};
				
				exec(success,error,"WeixinPay","openInvoiceAuthReq",[url]);
			}
	}
	
	module.exports = new WeixinPay();
	
	/**
	 * 兼容低版本
	 */
	navigator.weixinPayPlugin = {}
	navigator.weixinPayPlugin.pay = function(success,error,param){
		var data = param;
		navigator.weixinPay.pay({
			appid: param.appId,
			partnerid: param.partnerId,
			prepayid: param.prepayId,
            package: param.packageValue,
            noncestr: param.nonceStr,
            timestamp: param.timeStamp,
            sign: param.sign,
            success:function(code,msg){
            	success && success({responseMsg:msg,code:code});
            },
            error:function(code,msg){
            	error && error({responseMsg:msg,code:code});
            }
		});
	}
});