cordova.define("weixin.WeixinShare", function(require, exports, module) {
	var exec = require('cordova/exec');
	var ShareType = require('weixin.WeixinShareType');
	
	/**
	 * 微信分享对象
	 */
	var WeixinShare = function(){
		/**
		 * 回调方法map
		 */
		this.callback = {};
	}
	
	/**
	 * 微信分享方法定义
	 */
	WeixinShare.prototype = {
			/**
			 * 是否为空
			 */
			isNull:function(obj){
				return obj == null || obj == '' || obj.toString() == '';
			},
			/**
			 * 执行回调方法
			 */
			excuteCallback:function(errCode,errMsg){
				if(errCode == 0 || errCode == '0'){
					this.callback.success && this.callback.success(errCode,errMsg);
				}else{
					this.callback.error && this.callback.error(errCode,errMsg);
				}
			},
			/**
			 * 验证网页类型参数
			 */
			_validatePage:function(option){
				if(!this._validateText(option)){
					return false;
				}
				if(this.isNull(option.link)){
					return false;
				}
				return true;
			},
			/**
			 * 验证视频类型参数
			 */
			_validateVideo:function(option){
				if(!this._validateText(option)){
					return false;
				}
				if(this.isNull(option.video)){
					return false;
				}
				if(this.isNull(option.link)){
					return false;
				}
				return true;
			},
			/**
			 * 验证音乐类型参数
			 */
			_validateMusic:function(option){
				if(!this._validateText(option)){
					return false;
				}
				if(this.isNull(option.music)){
					return false;
				}
				if(this.isNull(option.link)){
					return false;
				}
				return true;
			},
			/**
			 * 验证图片类型参数
			 */
			_validateImage:function(option){

				
				
				if(this.isNull(option.image)){
					 
					return false;
				}
				
				return true;
			},

			/**
			 * 验证小程序类型参数
			 */
			_validateSoft:function(option){

				console.log("_validateSoft");
				
				if(this.isNull(option.userName)){
					 
					return false;
				}
				if(this.isNull(option.path)){
					 
					return false;
				}
				
				return true;
			},
			/**
			 * 验证文本类型参数
			 */
			_validateText:function(option){
				if(this.isNull(option)){
					return false;
				}
				if(this.isNull(option.title)){
					return false;
				}
				if(this.isNull(option.description)){
					return false;
				}
				return true;
			},
			/**
			 * 必填参数校验
			 */
			validate:function(type,option){
				var flag = false;
				switch(type){
					case ShareType.TEXT:
						flag = this._validateText(option);
						break;
					case ShareType.IMAGE:
						flag = this._validateImage(option);
						break;
					case ShareType.MUSIC:
						flag = this._validateMusic(option);
						break;
					case ShareType.VIDEO:
						flag = this._validateVideo(option);
						break;
					case ShareType.PAGE:
						flag = this._validatePage(option);
						break;
					case ShareType.SOFTWARE:
						flag = this._validateSoft(option);
						break;

				}
				this.callback = {
					success:option.success,
					error:option.error
				}
				return flag;
			},
			/**
			 * 将json参数转化成数组形式
			 */
			toArgs:function(scene,type,option){
				var args = [
					scene,
					type,
					option
				];
				return args;
			},
			/**
			 * 分享方法入口调用
			 * @param {WeinxShareScene} scene 分享的场景
			 * @param {WeixinShareType} type 分享类型
			 * @param {Object} option 分享参数
			 * @param {String} option.title 分享的标题
			 * @param {String} option.description 分享的描述
			 * @param {String} option.image 分享的图片
			 * @param {String} option.link 分享的链接
			 * @param {String} option.music 分享的音乐地址
			 * @param {String} option.video 分享的视频地址
			 * @param {String} option.page 分享的网页地址
			 *
			 * 
			 * @param {String} option.userName  分享的小程序原始ID
			 * @param {String} option.path  分享的小程path
			 *
			 * 
			 * @param {Function} option.success 分享的成功回调
			 * @param {Function} option.error 分享的失败回调
			 */
			share:function(scene,type,option){

				
				if(!this.validate(type,option)){
					return;
				}

			
				exec(option.success,option.error,"WeixinShare","share",this.toArgs(scene,type,option));
			}
	}
	
	module.exports = new WeixinShare();
});